@@ -29,7 +29,9 @@
 #include <Airports/dynamics.hxx>
 #include <Airports/airport.hxx>
 #include <Main/util.hxx>
+#include <Traffic/Schedule.hxx>
 
+#include <simgear/timing/sg_time.hxx>
 #include <simgear/structure/exception.hxx>
 
 #include <string>
@@ -39,7 +41,9 @@
 // defined in AIShip.cxx
 extern double fgIsFinite(double x);
 
+#include "AIManager.hxx"
 #include "AIAircraft.hxx"
+#include "AIFlightPlan.hxx"
 #include "performancedata.hxx"
 #include "performancedb.hxx"
 #include <signal.h>
@@ -53,7 +57,8 @@ using std::endl;
 FGAIAircraft::FGAIAircraft(FGAISchedule *ref) :
      /* HOT must be disabled for AI Aircraft,
       * otherwise traffic detection isn't working as expected.*/
-     FGAIBase(otAircraft, false) 
+    FGAIBase(otAircraft, false),
+    _performance(0)
 {
     trafficRef = ref;
     if (trafficRef) {
@@ -90,8 +95,13 @@ FGAIAircraft::FGAIAircraft(FGAISchedule *ref) :
     needsTaxiClearance = false;
     _needsGroundElevation = true;
 
-    _performance = 0; //TODO initialize to JET_TRANSPORT from PerformanceDB
-    dt = 0;
+    PerformanceDB* perfDB = globals->get_subsystem<PerformanceDB>();
+    if (perfDB) {
+        _performance = perfDB->getDefaultPerformance();
+    } else {
+        SG_LOG(SG_AI, SG_ALERT, "no performance DB found");
+    }
+
     takeOffStatus = 0;
 
     trackCache.remainingLength = 0;
@@ -133,10 +143,18 @@ void FGAIAircraft::update(double dt) {
     Transform();
 }
 
+void FGAIAircraft::unbind()
+{
+    FGAIBase::unbind();
+    clearATCController();
+}
+
 void FGAIAircraft::setPerformance(const std::string& acType, const std::string& acclass)
 {
-  static PerformanceDB perfdb; //TODO make it a global service
-  _performance = perfdb.getDataFor(acType, acclass);
+    PerformanceDB* perfDB = globals->get_subsystem<PerformanceDB>();
+    if (perfDB) {
+        _performance = perfDB->getDataFor(acType, acclass);
+    }
 }
 
 #if 0
@@ -145,12 +163,11 @@ void FGAIAircraft::setPerformance(const std::string& acType, const std::string&
   }
 #endif
 
- void FGAIAircraft::Run(double dt) {
-      FGAIAircraft::dt = dt;
-    
-     bool outOfSight = false, 
+ void FGAIAircraft::Run(double dt)
+{
+        bool outOfSight = false,
         flightplanActive = true;
-     updatePrimaryTargetValues(flightplanActive, outOfSight); // target hdg, alt, speed
+     updatePrimaryTargetValues(dt, flightplanActive, outOfSight); // target hdg, alt, speed
      if (outOfSight) {
         return;
      }
@@ -159,9 +176,9 @@ void FGAIAircraft::setPerformance(const std::string& acType, const std::string&
         groundTargetSpeed = 0;
      }
 
-     handleATCRequests(); // ATC also has a word to say
-     updateSecondaryTargetValues(); // target roll, vertical speed, pitch
-     updateActualState();
+     handleATCRequests(dt); // ATC also has a word to say
+     updateSecondaryTargetValues(dt); // target roll, vertical speed, pitch
+     updateActualState(dt);
 #if 0
    // 25/11/12 - added but disabled, since setting properties isn't
    // affecting the AI-model as expected.
@@ -408,6 +425,13 @@ double FGAIAircraft::calcVerticalSpeed(double vert_ft, double dist_m, double spe
     return vs;
 }
 
+void FGAIAircraft::clearATCController()
+{
+    controller = 0;
+    prevController = 0;
+    towerController = 0;
+}
+
 void FGAIAircraft::assertSpeed(double speed)
 {
     if ((speed < -50) || (speed > 1000)) {
@@ -581,8 +605,8 @@ void FGAIAircraft::announcePositionToController() {
             controller = trafficRef->getDepartureAirport()->getDynamics()->getStartupController();
         break;
     case 2:              // Taxiing to runway
-        if (trafficRef->getDepartureAirport()->getDynamics()->getGroundNetwork()->exists())
-            controller = trafficRef->getDepartureAirport()->getDynamics()->getGroundNetwork();
+        if (trafficRef->getDepartureAirport()->getDynamics()->getGroundController()->exists())
+            controller = trafficRef->getDepartureAirport()->getDynamics()->getGroundController();
         break;
     case 3:              //Take off tower controller
         if (trafficRef->getDepartureAirport()->getDynamics()) {
@@ -593,13 +617,13 @@ void FGAIAircraft::announcePositionToController() {
         }
         break;
     case 6:
-         if (trafficRef->getDepartureAirport()->getDynamics()) {
+         if (trafficRef->getArrivalAirport()->getDynamics()) {
              controller = trafficRef->getArrivalAirport()->getDynamics()->getApproachController();
           }
           break;
     case 8:              // Taxiing for parking
-        if (trafficRef->getArrivalAirport()->getDynamics()->getGroundNetwork()->exists())
-            controller = trafficRef->getArrivalAirport()->getDynamics()->getGroundNetwork();
+        if (trafficRef->getArrivalAirport()->getDynamics()->getGroundController()->exists())
+            controller = trafficRef->getArrivalAirport()->getDynamics()->getGroundController();
         break;
     default:
         controller = 0;
@@ -974,11 +998,12 @@ void FGAIAircraft::controlSpeed(FGAIWaypoint* curr, FGAIWaypoint* next) {
 /**
  * Update target values (heading, alt, speed) depending on flight plan or control properties
  */
-void FGAIAircraft::updatePrimaryTargetValues(bool& flightplanActive, bool& aiOutOfSight) {
+void FGAIAircraft::updatePrimaryTargetValues(double dt, bool& flightplanActive, bool& aiOutOfSight) {
     if (fp)                      // AI object has a flightplan
     {
         //TODO make this a function of AIBase
-        time_t now = time(NULL) + fgGetLong("/sim/time/warp");
+        time_t now = globals->get_time_params()->get_cur_time();
+
         //cerr << "UpateTArgetValues() " << endl;
         ProcessFlightPlan(dt, now);
 
@@ -1036,7 +1061,7 @@ void FGAIAircraft::updatePrimaryTargetValues(bool& flightplanActive, bool& aiOut
     }
 }
 
-void FGAIAircraft::updateHeading() {
+void FGAIAircraft::updateHeading(double dt) {
     // adjust heading based on current bank angle
     if (roll == 0.0)
         roll = 0.01;
@@ -1170,7 +1195,7 @@ void FGAIAircraft::updateBankAngleTarget() {
 }
 
 
-void FGAIAircraft::updateVerticalSpeedTarget() {
+void FGAIAircraft::updateVerticalSpeedTarget(double dt) {
     // adjust target Altitude, based on ground elevation when on ground
     if (onGround()) {
         getGroundElev(dt);
@@ -1233,7 +1258,8 @@ const string& FGAIAircraft::atGate()
      return empty;
 }
 
-void FGAIAircraft::handleATCRequests() {
+void FGAIAircraft::handleATCRequests(double dt)
+{
     //TODO implement NullController for having no ATC to save the conditionals
     if (controller) {
         controller->updateAircraftInformation(getID(),
@@ -1254,7 +1280,8 @@ void FGAIAircraft::handleATCRequests() {
     }
 }
 
-void FGAIAircraft::updateActualState() {
+void FGAIAircraft::updateActualState(double dt)
+{
     //update current state
     //TODO have a single tgt_speed and check speed limit on ground on setting tgt_speed
     double distance = speed * SG_KT_TO_MPS * dt;
@@ -1266,7 +1293,7 @@ void FGAIAircraft::updateActualState() {
     else
         speed = _performance->actualSpeed(this, (tgt_speed *speedFraction), dt, false);
     //assertSpeed(speed);
-    updateHeading();
+    updateHeading(dt);
     roll = _performance->actualBankAngle(this, tgt_roll, dt);
 
     // adjust altitude (meters) based on current vertical speed (fpm)
@@ -1277,10 +1304,10 @@ void FGAIAircraft::updateActualState() {
     pitch = _performance->actualPitch(this, tgt_pitch, dt);
 }
 
-void FGAIAircraft::updateSecondaryTargetValues() {
+void FGAIAircraft::updateSecondaryTargetValues(double dt) {
     // derived target state values
     updateBankAngleTarget();
-    updateVerticalSpeedTarget();
+    updateVerticalSpeedTarget(dt);
     updatePitchAngleTarget();
 
     //TODO calculate wind correction angle (tgt_yaw)
@@ -1370,7 +1397,7 @@ time_t FGAIAircraft::checkForArrivalTime(const string& wptName) {
      } else {
          return 0;
      }
-     time_t now = time(NULL) + fgGetLong("/sim/time/warp");
+     time_t now = globals->get_time_params()->get_cur_time();
      time_t arrivalTime = fp->getArrivalTime();
      
      time_t ete = tracklength / ((speed * SG_NM_TO_METER) / 3600.0); 
