@@ -109,7 +109,7 @@ public:
     bool hasInteriorPath(void) { return _hasInteriorPath;}
     inline std::string& getInteriorPath() { return _interiorPath; }
 private:
-    std::auto_ptr<FGNasalModelDataProxy> _nasal;
+    std::unique_ptr<FGNasalModelDataProxy> _nasal;
     std::string _fxpath;
     bool _ready;
     bool _initialized;
@@ -397,7 +397,7 @@ bool FGAIBase::init(bool search_in_AI_path)
         BOOST_FOREACH(SGPath p, globals->get_data_paths("AI")) {
             p.append(model_path);
             if (p.exists()) {
-                f = p.str();
+                f = p.local8BitStr();
                 break;
             }
         } // of AI data paths iteration
