@@ -28,8 +28,10 @@
 #include <simgear/sg_inlines.h>
 #include <simgear/math/sg_geodesy.hxx>
 
-#include <math.h>
+#include <cmath>
 #include <Main/util.hxx>
+#include <Main/globals.hxx>
+#include <Main/fg_props.hxx>
 
 #include "AICarrier.hxx"
 
