@@ -30,9 +30,10 @@
 #include <simgear/math/sg_geodesy.hxx>
 #include <simgear/math/sg_random.h>
 
-#include <math.h>
+#include <cmath>
 #include <Main/util.hxx>
-#include <Viewer/viewer.hxx>
+#include <Main/globals.hxx>
+#include <Viewer/view.hxx>
 
 #include <Scenery/scenery.hxx>
 
