@@ -27,22 +27,30 @@
 #include <iostream>
 
 #include <Airports/dynamics.hxx>
+#include <Airports/airportdynamicsmanager.hxx>
 #include <Airports/airport.hxx>
 #include <Scenery/scenery.hxx>
+#include <Main/globals.hxx>
+#include <Main/fg_props.hxx>
+#include <AIModel/AIAircraft.hxx>
+#include <Traffic/Schedule.hxx>
+#include <Traffic/SchedFlight.hxx>
+#include <AIModel/AIFlightPlan.hxx>
+
 #include "atc_mgr.hxx"
 
 
 using std::string;
 
-FGATCManager::FGATCManager() {
-    controller = 0;
-    prevController = 0;
-    networkVisible = false;
-    initSucceeded  = false;
+FGATCManager::FGATCManager() :
+    controller(NULL),
+    prevController(NULL),
+    networkVisible(false),
+    initSucceeded(false)
+{
 }
 
 FGATCManager::~FGATCManager() {
-
 }
 
 void FGATCManager::init() {
@@ -73,12 +81,12 @@ void FGATCManager::init() {
     double speed     = fgGetDouble("/velocities/groundspeed-kt");
     double aircraftRadius = 40; // note that this is currently hardcoded to a one-size-fits all JumboJet value. Should change later;
 
-
-    ai_ac.setCallSign ( callsign  );
-    ai_ac.setLongitude( longitude );
-    ai_ac.setLatitude ( latitude  );
-    ai_ac.setAltitude ( altitude  );
-    ai_ac.setPerformance("", "jet_transport");
+    ai_ac = new FGAIAircraft;
+    ai_ac->setCallSign ( callsign  );
+    ai_ac->setLongitude( longitude );
+    ai_ac->setLatitude ( latitude  );
+    ai_ac->setAltitude ( altitude  );
+    ai_ac->setPerformance("", "jet_transport");
 
     // NEXT UP: Create a traffic Schedule and fill that with appropriate information. This we can use to flight planning.
     // Note that these are currently only defaults. 
@@ -94,7 +102,7 @@ void FGATCManager::init() {
     
     trafficRef->assign(flight);
     FGAIFlightPlan *fp = 0; 
-    ai_ac.setTrafficRef(trafficRef);
+    ai_ac->setTrafficRef(trafficRef);
     
     string flightPlanName = airport + "-" + airport + ".xml";
     //double cruiseAlt = 100; // Doesn't really matter right now.
@@ -102,16 +110,17 @@ void FGATCManager::init() {
     //time_t deptime = 0;        // just make sure how flightplan processing is affected by this...
 
 
-    FGAirport *apt = FGAirport::findByIdent(airport); 
-    if (apt && onGround) {// && !runway.empty()) {
-        FGAirportDynamics* dcs = apt->getDynamics();
+    FGAirportDynamicsRef dcs(flightgear::AirportDynamicsManager::find(airport));
+    if (dcs && onGround) {// && !runway.empty()) {
+
         ParkingAssignment pk(dcs->getParkingByName(parking));
       
         // No valid parking location, so either at the runway or at a random location.
         if (pk.isValid()) {
+            dcs->setParkingAvailable(pk.parking(), false);
             fp = new FGAIFlightPlan;
-            controller = apt->getDynamics()->getStartupController();
-            int stationFreq = apt->getDynamics()->getGroundFrequency(1);
+            controller = dcs->getStartupController();
+            int stationFreq = dcs->getGroundFrequency(1);
             if (stationFreq > 0)
             {
                 //cerr << "Setting radio frequency to : " << stationFreq << endl;
@@ -125,9 +134,9 @@ void FGATCManager::init() {
             string aircraftType; // Unused.
             string airline;      // Currently used for gate selection, but a fallback mechanism will apply when not specified.
             fp->setGate(pk);
-            if (!(fp->createPushBack(&ai_ac,
+            if (!(fp->createPushBack(ai_ac,
                                      false,
-                                     apt,
+                                     dcs->parent(),
                                      aircraftRadius,
                                      fltType,
                                      aircraftType,
@@ -139,8 +148,8 @@ void FGATCManager::init() {
             
             
         } else if (!runway.empty()) {
-            controller = apt->getDynamics()->getTowerController();
-            int stationFreq = apt->getDynamics()->getTowerFrequency(2);
+            controller = dcs->getTowerController();
+            int stationFreq = dcs->getTowerFrequency(2);
             if (stationFreq > 0)
             {
                 //cerr << "Setting radio frequency to in airfrequency: " << stationFreq << endl;
@@ -150,8 +159,8 @@ void FGATCManager::init() {
             leg = 3;
             string fltType = "ga";
             fp->setRunway(runway);
-            fp->createTakeOff(&ai_ac, false, apt, 0, fltType);
-            ai_ac.setTakeOffStatus(2);
+            fp->createTakeOff(ai_ac, false, dcs->parent(), 0, fltType);
+            ai_ac->setTakeOffStatus(2);
         } else {
                 // We're on the ground somewhere. Handle this case later.
         }
@@ -168,12 +177,12 @@ void FGATCManager::init() {
     if (fp) {
         fp->restart();
         fp->setLeg(leg);
-        ai_ac.SetFlightPlan(fp);
+        ai_ac->SetFlightPlan(fp);
     }
     if (controller) {
-        controller->announcePosition(ai_ac.getID(), fp, fp->getCurrentWaypoint()->getRouteIndex(),
-                                      ai_ac._getLatitude(), ai_ac._getLongitude(), heading, speed, altitude,
-                                      aircraftRadius, leg, &ai_ac);
+        controller->announcePosition(ai_ac->getID(), fp, fp->getCurrentWaypoint()->getRouteIndex(),
+                                      ai_ac->_getLatitude(), ai_ac->_getLongitude(), heading, speed, altitude,
+                                      aircraftRadius, leg, ai_ac);
 
     //dialog.init();
 
@@ -181,20 +190,35 @@ void FGATCManager::init() {
    //cerr << "Adding groundnetWork to the scenegraph::init" << endl;
    //globals->get_scenery()->get_scene_graph()->addChild(node);
    }
-   initSucceeded = true;
+    initSucceeded = true;
+}
+
+void FGATCManager::shutdown()
+{
+    ai_ac.clear();
+    activeStations.clear();
 }
 
 void FGATCManager::addController(FGATCController *controller) {
     activeStations.push_back(controller);
 }
 
+void FGATCManager::removeController(FGATCController *controller)
+{
+    AtcVecIterator it;
+    it = std::find(activeStations.begin(), activeStations.end(), controller);
+    if (it != activeStations.end()) {
+        activeStations.erase(it);
+    }
+}
+
 void FGATCManager::update ( double time ) {
     //cerr << "ATC update code is running at time: " << time << endl;
     // Test code: let my virtual co-pilot handle ATC:
    
     
 
-    FGAIFlightPlan *fp = ai_ac.GetFlightPlan();
+    FGAIFlightPlan *fp = ai_ac->GetFlightPlan();
         
     /* test code : find out how the routing develops */
     if (fp) {
@@ -208,16 +232,19 @@ void FGATCManager::update ( double time ) {
             //cerr << "Shutting down the atc_mgr" << endl;
             return;
         }
-        //cerr << "Size of waypoint cue " << size << " ";
-        //for (int i = 0; i < size; i++) {
-        //    int val = fp->getRouteIndex(i);
-            //cerr << fp->getWayPoint(i)->getName() << " ";
+#if 0
+        // Test code: Print how far we're progressing along the taxi route. 
+        //std::cerr << "Size of waypoint cue " << size << " ";
+        for (int i = 0; i < size; i++) {
+            int val = fp->getRouteIndex(i);
+            //std::cerr << fp->getWayPoint(i)->getName() << " ";
             //if ((val) && (val != pos)) {
-                //intentions.push_back(val);
-                //cerr << "[done ] " << endl;
+            //    intentions.push_back(val);
+            //    std::cerr << "[done ] " << std::endl;
             //}
-        //}
-        //cerr << "[done ] " << endl;
+        }
+        //std::cerr << "[done ] " << std::endl;
+#endif
     }
     if (fp) {
         //cerr << "Currently at leg : " << fp->getLeg() << endl;
@@ -245,20 +272,20 @@ void FGATCManager::update ( double time ) {
     
     cerr << "Bearing to nearest waypoint : " << course1 << " " << dist1 << ". (course " << course2 << ")." <<  endl;
     */
-    ai_ac.setLatitude(latitude);
-    ai_ac.setLongitude(longitude);
-    ai_ac.setAltitude(altitude);
-    ai_ac.setHeading(heading);
-    ai_ac.setSpeed(speed);
-    ai_ac.update(time);
-    controller = ai_ac.getATCController();
+    ai_ac->setLatitude(latitude);
+    ai_ac->setLongitude(longitude);
+    ai_ac->setAltitude(altitude);
+    ai_ac->setHeading(heading);
+    ai_ac->setSpeed(speed);
+    ai_ac->update(time);
+    controller = ai_ac->getATCController();
     FGATCDialogNew::instance()->update(time);
     if (controller) {
        //cerr << "name of previous waypoint : " << fp->getPreviousWaypoint()->getName() << endl;
 
         //cerr << "Running FGATCManager::update()" << endl;
         //cerr << "Currently under control of " << controller->getName() << endl;
-        controller->updateAircraftInformation(ai_ac.getID(),
+        controller->updateAircraftInformation(ai_ac->getID(),
                                               latitude,
                                               longitude,
                                               heading,
