@@ -459,6 +459,10 @@ bool FGTrafficRecord::isOpposing(FGGroundNetwork * net,
 
 bool FGTrafficRecord::isActive(int margin) const
 {
+    if (aircraft->getDie()) {
+        return false;
+    }
+    
     time_t now = globals->get_time_params()->get_cur_time();
     time_t deptime = aircraft->getTrafficRef()->getDepartureTime();
     return ((now + margin) > deptime);
@@ -839,6 +843,26 @@ void FGATCController::init()
     }
 }
 
+class AircraftIsDead
+{
+public:
+    bool operator()(const FGTrafficRecord& traffic) const
+    {
+        if (!traffic.getAircraft()) {
+            return true;
+        }
+
+        return traffic.getAircraft()->getDie();
+    }
+};
+
+void FGATCController::eraseDeadTraffic(TrafficVector& vec)
+{
+    TrafficVector::iterator it = std::remove_if(vec.begin(), vec.end(), AircraftIsDead());
+    vec.erase(it, vec.end());
+}
+
+
 /***************************************************************************
  * class FGTowerController
  *
@@ -1108,7 +1132,7 @@ string FGTowerController::getName() {
 
 void FGTowerController::update(double dt)
 {
-
+    eraseDeadTraffic(activeTraffic);
 }
 
 
@@ -1392,6 +1416,7 @@ void FGStartupController::render(bool visible)
         //double elevation_meters = 0.0;
         //double elevation_feet = 0.0;
 
+        FGGroundNetwork* groundNet = parent->parent()->groundNetwork();
 
         //for ( FGTaxiSegmentVectorIterator i = segments.begin(); i != segments.end(); i++) {
         double dx = 0;
@@ -1403,7 +1428,7 @@ void FGStartupController::render(bool visible)
                 int pos = i->getCurrentPosition();
                 //cerr << "rendering for " << i->getAircraft()->getCallSign() << "pos = " << pos << endl;
                 if (pos > 0) {
-                    FGTaxiSegment *segment  = parent->getGroundNetwork()->findSegment(pos);
+                    FGTaxiSegment *segment = groundNet->findSegment(pos);
                     SGGeod start(SGGeod::fromDeg((i->getLongitude()), (i->getLatitude())));
                     SGGeod end  (segment->getEnd()->geod());
 
@@ -1488,7 +1513,7 @@ void FGStartupController::render(bool visible)
                         //cerr << "rendering for " << i->getAircraft()->getCallSign() << "intention = " << k << endl;
                         osg::MatrixTransform *obj_trans = new osg::MatrixTransform;
                         obj_trans->setDataVariance(osg::Object::STATIC);
-                        FGTaxiSegment *segment  = parent->getGroundNetwork()->findSegment(k);
+                        FGTaxiSegment *segment  = groundNet->findSegment(k);
 
                         double elevationStart = segment->getStart()->getElevationM();
                         double elevationEnd   = segment->getEnd  ()->getElevationM();
@@ -1572,7 +1597,7 @@ string FGStartupController::getName() {
 
 void FGStartupController::update(double dt)
 {
-
+    eraseDeadTraffic(activeTraffic);
 }
 
 
@@ -1706,11 +1731,9 @@ void FGApproachController::signOff(int id)
 
 void FGApproachController::update(double dt)
 {
-
+    eraseDeadTraffic(activeTraffic);
 }
 
-
-
 bool FGApproachController::hasInstruction(int id)
 {
     TrafficVectorIterator i = activeTraffic.begin();
