@@ -24,8 +24,9 @@
 #include "dynamicloader.hxx"
 
 #include <Navaids/NavDataCache.hxx>
-#include <Airports/dynamics.hxx>
 #include <Airports/airport.hxx>
+#include <Airports/dynamics.hxx>
+#include <Airports/groundnetwork.hxx>
 
 using std::string;
 
@@ -52,36 +53,37 @@ static double processPosition(const string &pos)
   return value;
 }
 
-FGAirportDynamicsXMLLoader::FGAirportDynamicsXMLLoader(FGAirportDynamics* dyn):
-    XMLVisitor(), _dynamics(dyn)
+FGGroundNetXMLLoader::FGGroundNetXMLLoader(FGGroundNetwork* net):
+    XMLVisitor(),
+    _groundNetwork(net)
 {}
 
-void  FGAirportDynamicsXMLLoader::startXML () {
+void  FGGroundNetXMLLoader::startXML () {
   //cout << "FGAirportDynamicsLoader::Start XML" << endl;
 }
 
-void  FGAirportDynamicsXMLLoader::endXML ()
+void  FGGroundNetXMLLoader::endXML ()
 {
-  std::map<PositionedID, int>::iterator it;
-  flightgear::NavDataCache* cache = flightgear::NavDataCache::instance();
+  ParkingPushbackIndex::const_iterator it;
   
   for (it = _parkingPushbacks.begin(); it != _parkingPushbacks.end(); ++it) {
-    std::map<int, PositionedID>::iterator j = _idMap.find(it->second);
-    if (j == _idMap.end()) {
+    NodeIndexMap::const_iterator j = _indexMap.find(it->second);
+    if (j == _indexMap.end()) {
       SG_LOG(SG_NAVAID, SG_WARN, "bad groundnet, no node for index:" << it->first);
       continue;
     }
+
+    it->first->setPushBackPoint(j->second);
     
-    cache->setParkingPushBackRoute(it->first, j->second);
   }
   
-  BOOST_FOREACH(PositionedID id, _unreferencedNodes) {
-    SG_LOG(SG_NAVAID, SG_WARN, "unreferenced groundnet node:" << id);
+  BOOST_FOREACH(FGTaxiNodeRef node, _unreferencedNodes) {
+    SG_LOG(SG_NAVAID, SG_WARN, "unreferenced groundnet node:" << node->ident());
   }
   
 }
 
-void FGAirportDynamicsXMLLoader::startParking(const XMLAttributes &atts)
+void FGGroundNetXMLLoader::startParking(const XMLAttributes &atts)
 {
   string type;
   int index = 0;
@@ -124,17 +126,19 @@ void FGAirportDynamicsXMLLoader::startParking(const XMLAttributes &atts)
  
   SGGeod pos(SGGeod::fromDeg(processPosition(lon), processPosition(lat)));
   
-  PositionedID guid = flightgear::NavDataCache::instance()->insertParking(gateName + gateNumber, pos,
-                                                      _dynamics->parent()->guid(),
-                                                      heading, radius, type, airlineCodes);
+  FGParkingRef parking(new FGParking(index,
+                                     pos, heading, radius,
+                                     gateName + gateNumber,
+                                     type, airlineCodes));
   if (pushBackRoute > 0) {
-    _parkingPushbacks[guid] = pushBackRoute;
+    _parkingPushbacks[parking] = pushBackRoute;
   }
   
-  _idMap[index] = guid;
+  _indexMap[index] = parking;
+  _groundNetwork->addParking(parking);
 }
 
-void FGAirportDynamicsXMLLoader::startNode(const XMLAttributes &atts)
+void FGGroundNetXMLLoader::startNode(const XMLAttributes &atts)
 {
   int index = 0;
   string lat, lon;
@@ -168,18 +172,17 @@ void FGAirportDynamicsXMLLoader::startNode(const XMLAttributes &atts)
     }
 	}
   
-  if (_idMap.find(index) != _idMap.end()) {
+  if (_indexMap.find(index) != _indexMap.end()) {
     SG_LOG(SG_NAVAID, SG_WARN, "duplicate ground-net index:" << index);
   }
   
   SGGeod pos(SGGeod::fromDeg(processPosition(lon), processPosition(lat)));
-  PositionedID guid = flightgear::NavDataCache::instance()->insertTaxiNode(pos,
-    _dynamics->parent()->guid(), holdPointType, onRunway);
-  _idMap[index] = guid;
-  _unreferencedNodes.insert(guid);
+  FGTaxiNodeRef node(new FGTaxiNode(index, pos, onRunway, holdPointType));
+  _indexMap[index] = node;
+  _unreferencedNodes.insert(node);
 }
 
-void FGAirportDynamicsXMLLoader::startArc(const XMLAttributes &atts)
+void FGGroundNetXMLLoader::startArc(const XMLAttributes &atts)
 {  
   int begin = 0, end = 0;
   bool isPushBackRoute = false;
@@ -197,23 +200,38 @@ void FGAirportDynamicsXMLLoader::startArc(const XMLAttributes &atts)
   
   IntPair e(begin, end);
   if (_arcSet.find(e) != _arcSet.end()) {
-    SG_LOG(SG_NAVAID, SG_WARN, _dynamics->parent()->ident() << " ground-net: skipping duplicate edge:" << begin << "->" << end);
+    SG_LOG(SG_NAVAID, SG_WARN, _groundNetwork->airport()->ident() << " ground-net: skipping duplicate edge:" << begin << "->" << end);
     return;
   }
   
-  _arcSet.insert(e);
-  flightgear::NavDataCache::instance()->insertGroundnetEdge(_dynamics->parent()->guid(),
-                                                            _idMap[begin], _idMap[end]);
-  
-  _unreferencedNodes.erase(_idMap[begin]);
-  _unreferencedNodes.erase(_idMap[end]);
-  
+  NodeIndexMap::const_iterator it;
+  FGTaxiNodeRef fromNode, toNode;
+  it = _indexMap.find(begin);
+  if (it == _indexMap.end()) {
+      SG_LOG(SG_NAVAID, SG_WARN, "ground-net: bad edge:" << begin << "->" << end << ", begin index unknown");
+      return;
+  } else {
+      _unreferencedNodes.erase(it->second);
+      fromNode = it->second;
+  }
+
+  it = _indexMap.find(end);
+  if (it == _indexMap.end()) {
+      SG_LOG(SG_NAVAID, SG_WARN, "ground-net: bad edge:" << begin << "->" << end << ", end index unknown");
+      return;
+  } else {
+      _unreferencedNodes.erase(it->second);
+      toNode = it->second;
+  }
+
+  _arcSet.insert(e);  
+  _groundNetwork->addSegment(fromNode, toNode);
   if (isPushBackRoute) {
-    flightgear::NavDataCache::instance()->markGroundnetAsPushback(_idMap[end]);
+//    toNode->setIsPushback();
   }
 }
 
-void FGAirportDynamicsXMLLoader::startElement (const char * name, const XMLAttributes &atts)
+void FGGroundNetXMLLoader::startElement (const char * name, const XMLAttributes &atts)
 {
   if (!strcmp("Parking", name)) {
     startParking(atts);
@@ -224,27 +242,27 @@ void FGAirportDynamicsXMLLoader::startElement (const char * name, const XMLAttri
   }
 }
 
-void  FGAirportDynamicsXMLLoader::endElement (const char * name)
+void  FGGroundNetXMLLoader::endElement (const char * name)
 {
   int valueAsInt = atoi(value.c_str());
   if (!strcmp("version", name)) {
-    _dynamics->getGroundNetwork()->addVersion(valueAsInt);
+    _groundNetwork->addVersion(valueAsInt);
   } else if (!strcmp("AWOS", name)) {
-    _dynamics->addAwosFreq(valueAsInt);
+    _groundNetwork->addAwosFreq(valueAsInt);
   } else if (!strcmp("UNICOM", name)) {
-    _dynamics->addUnicomFreq(valueAsInt);
+    _groundNetwork->addUnicomFreq(valueAsInt);
   } else if (!strcmp("CLEARANCE", name)) {
-    _dynamics->addClearanceFreq(valueAsInt);
+    _groundNetwork->addClearanceFreq(valueAsInt);
   } else if (!strcmp("GROUND", name)) {
-    _dynamics->addGroundFreq(valueAsInt);
+    _groundNetwork->addGroundFreq(valueAsInt);
   } else if (!strcmp("TOWER", name)) {
-    _dynamics->addTowerFreq(valueAsInt);
+    _groundNetwork->addTowerFreq(valueAsInt);
   } else if (!strcmp("APPROACH", name)) {
-    _dynamics->addApproachFreq(valueAsInt);
+    _groundNetwork->addApproachFreq(valueAsInt);
   }
 }
 
-void  FGAirportDynamicsXMLLoader::data (const char * s, int len) {
+void  FGGroundNetXMLLoader::data (const char * s, int len) {
   string token = string(s,len);
   //cout << "Character data " << string(s,len) << endl;
   if ((token.find(" ") == string::npos && (token.find('\n')) == string::npos))
@@ -253,14 +271,14 @@ void  FGAirportDynamicsXMLLoader::data (const char * s, int len) {
     value = string("");
 }
 
-void  FGAirportDynamicsXMLLoader::pi (const char * target, const char * data) {
+void  FGGroundNetXMLLoader::pi (const char * target, const char * data) {
   //cout << "Processing instruction " << target << ' ' << data << endl;
 }
 
-void  FGAirportDynamicsXMLLoader::warning (const char * message, int line, int column) {
+void  FGGroundNetXMLLoader::warning (const char * message, int line, int column) {
   SG_LOG(SG_IO, SG_WARN, "Warning: " << message << " (" << line << ',' << column << ')');
 }
 
-void  FGAirportDynamicsXMLLoader::error (const char * message, int line, int column) {
+void  FGGroundNetXMLLoader::error (const char * message, int line, int column) {
   SG_LOG(SG_IO, SG_ALERT, "Error: " << message << " (" << line << ',' << column << ')');
 }
