@@ -51,6 +51,8 @@ using std::vector;
 using std::sort;
 using std::random_shuffle;
 
+// #define RUNWAY_FALLBACK_DEBUG
+
 class ParkingAssignment::ParkingAssignmentPrivate
 {
 public:
@@ -180,7 +182,7 @@ FGParking* FGAirportDynamics::innerGetAvailableParking(double radius, const stri
                                            const string & airline,
                                            bool skipEmptyAirlineCode)
 {
-    const FGParkingList& parkings(getGroundNetwork()->allParkings());
+    const FGParkingList& parkings(parent()->groundNetwork()->allParkings());
     FGParkingList::const_iterator it;
     for (it = parkings.begin(); it != parkings.end(); ++it) {
         FGParkingRef parking = *it;
@@ -207,7 +209,7 @@ FGParking* FGAirportDynamics::innerGetAvailableParking(double radius, const stri
 
 bool FGAirportDynamics::hasParkings() const
 {
-    return !getGroundNetwork()->allParkings().empty();
+    return !parent()->groundNetwork()->allParkings().empty();
 }
 
 ParkingAssignment FGAirportDynamics::getAvailableParking(double radius, const string & flType,
@@ -235,7 +237,7 @@ ParkingAssignment FGAirportDynamics::getAvailableParking(double radius, const st
 
 ParkingAssignment FGAirportDynamics::getParkingByName(const std::string& name) const
 {
-    const FGParkingList& parkings(getGroundNetwork()->allParkings());
+    const FGParkingList& parkings(parent()->groundNetwork()->allParkings());
     FGParkingList::const_iterator it;
     for (it = parkings.begin(); it != parkings.end(); ++it) {
         if ((*it)->name() == name) {
@@ -246,11 +248,6 @@ ParkingAssignment FGAirportDynamics::getParkingByName(const std::string& name) c
     return ParkingAssignment();
 }
 
-FGGroundNetwork *FGAirportDynamics::getGroundNetwork() const
-{
-    return _ap->groundNetwork();
-}
-
 void FGAirportDynamics::setParkingAvailable(FGParking* park, bool available)
 {
   if (available) {
@@ -302,7 +299,7 @@ public:
 
 FGParkingList FGAirportDynamics::getParkings(bool onlyAvailable, const std::string &type) const
 {
-    FGParkingList result(getGroundNetwork()->allParkings());
+    FGParkingList result(parent()->groundNetwork()->allParkings());
 
     GetParkingsPredicate pred(onlyAvailable, type, this);
     FGParkingList::iterator it = std::remove_if(result.begin(), result.end(), pred);
@@ -516,6 +513,8 @@ string FGAirportDynamics::fallbackGetActiveRunway(int action, double heading)
 
         std::sort(groups.begin(), groups.end(), GroupSortByScore());
 
+        // debugging fallback runway assignments
+#if defined(RUNWAY_FALLBACK_DEBUG)
         {
             ostringstream os;
             os << parent()->ident() << " groups:";
@@ -527,6 +526,7 @@ string FGAirportDynamics::fallbackGetActiveRunway(int action, double heading)
             std::string s = os.str();
             SG_LOG(SG_AI, SG_INFO, s);
         }
+#endif
 
         // assign takeoff and landing runways
         FallbackRunwayGroup bestGroup = groups.front();
@@ -537,6 +537,7 @@ string FGAirportDynamics::fallbackGetActiveRunway(int action, double heading)
         _fallbackArrivalRunways.clear();
         bestGroup.getRunways(_fallbackArrivalRunways, _fallbackDepartureRunways);
 
+#if defined(RUNWAY_FALLBACK_DEBUG)
         ostringstream os;
         os << "\tArrival:" << _fallbackArrivalRunways.front()->ident();
         for (unsigned int r=1; r <_fallbackArrivalRunways.size(); ++r) {
@@ -550,6 +551,7 @@ string FGAirportDynamics::fallbackGetActiveRunway(int action, double heading)
         std::string s = os.str();
         SG_LOG(SG_AI, SG_INFO, parent()->ident() << " fallback runways assignments for "
                << static_cast<int>(windHeading) << "@" << static_cast<int>(windSpeed) << "\n" << s);
+#endif
     }
 
     _fallbackRunwayCounter++;
@@ -770,7 +772,7 @@ int FGAirportDynamics::getGroundFrequency(unsigned leg)
                "Leg value is smaller than one at " << SG_ORIGIN);
     }
 
-    const intVec& freqGround(getGroundNetwork()->getGroundFrequencies());
+    const intVec& freqGround(parent()->groundNetwork()->getGroundFrequencies());
 
     if (freqGround.size() == 0) {
         return 0;
@@ -796,7 +798,7 @@ int FGAirportDynamics::getTowerFrequency(unsigned nr)
                "Leg value is smaller than two at " << SG_ORIGIN);
     }
 
-    const intVec& freqTower(getGroundNetwork()->getTowerFrequencies());
+    const intVec& freqTower(parent()->groundNetwork()->getTowerFrequencies());
 
     if (freqTower.size() == 0) {
         return 0;
