@@ -48,16 +48,16 @@ namespace canvas
     (
       SG_GL,
       SG_INFO,
-      "canvas::Text: using font file " << path.str()
+      "canvas::Text: using font file " << path
     );
 
-    simgear::canvas::FontPtr font = osgText::readFontFile(path.c_str());
+    simgear::canvas::FontPtr font = osgText::readFontFile(path.local8BitStr());
     if( !font )
       SG_LOG
       (
         SG_GL,
         SG_ALERT,
-        "canvas::Text: Failed to open font file " << path.c_str()
+        "canvas::Text: Failed to open font file " << path
       );
 
     return font;
@@ -79,11 +79,12 @@ namespace canvas
   //----------------------------------------------------------------------------
   osg::ref_ptr<osg::Image> FGCanvasSystemAdapter::getImage(const std::string& path) const
   {
-    if( SGPath(path).isAbsolute() )
+      SGPath p(SGPath::fromUtf8(path));
+    if( p.isAbsolute() )
     {
-      std::string valid_path = fgValidatePath(path, false);
-      if( !valid_path.empty() )
-        return osgDB::readImageFile(valid_path.c_str());
+      SGPath valid_path = fgValidatePath(p, false);
+      if( !valid_path.isNull() )
+        return osgDB::readImageFile(valid_path.local8BitStr());
 
       SG_LOG(SG_IO, SG_ALERT, "canvas::Image: reading '" << path << "' denied");
     }
@@ -91,7 +92,7 @@ namespace canvas
     {
       SGPath tpath = globals->resolve_resource_path(path);
       if( !tpath.isNull() )
-        return osgDB::readRefImageFile(tpath.c_str());
+        return osgDB::readRefImageFile(tpath.local8BitStr());
 
       SG_LOG(SG_IO, SG_ALERT, "canvas::Image: No such image: '" << path << "'");
     }
