@@ -261,7 +261,7 @@ public:
 private:
     SymbolDef* definition;
     
-    std::auto_ptr<SGCondition> enable;
+    std::unique_ptr<SGCondition> enable;
     string_set required_states;
     string_set excluded_states;
 };
@@ -350,7 +350,7 @@ public:
     bool rotateToHeading;
     bool roundPos; ///< should position be rounded to integer values
     bool hasText;
-    std::auto_ptr<SGCondition> textEnable;
+    std::unique_ptr<SGCondition> textEnable;
     bool textEnabled; ///< cache condition result
     osg::Vec4 textColor;
     osg::Vec2 textOffset;
@@ -780,7 +780,7 @@ NavDisplay::updateFont()
     }
 
     osg::ref_ptr<osgDB::ReaderWriter::Options> fontOptions = new osgDB::ReaderWriter::Options("monochrome");
-    osg::ref_ptr<osgText::Font> font = osgText::readFontFile(tpath.c_str(), fontOptions.get());
+    osg::ref_ptr<osgText::Font> font = osgText::readFontFile(tpath.local8BitStr(), fontOptions.get());
 
     if (font != 0) {
         _font = font;
