@@ -54,7 +54,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_FDMEXEC "$Id: FGFDMExec.h,v 1.95 2015/02/07 17:52:36 bcoconni Exp $"
+#define ID_FDMEXEC "$Id: FGFDMExec.h,v 1.105 2016/04/16 12:24:39 bcoconni Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -178,7 +178,7 @@ CLASS DOCUMENTATION
                                 property actually maps toa function call of DoTrim().
 
     @author Jon S. Berndt
-    @version $Revision: 1.95 $
+    @version $Revision: 1.105 $
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -311,7 +311,7 @@ public:
                       is not given in either place, an error will result.
       @return true if successfully loads; false otherwise. */
   bool LoadScript(const std::string& Script, double deltaT=0.0,
-                  const std::string initfile="");
+                  const std::string& initfile="");
 
   /** Sets the path to the engine config file directories.
       @param path path to the directory under which engine config
@@ -361,6 +361,8 @@ public:
   FGAuxiliary* GetAuxiliary(void)      {return (FGAuxiliary*)Models[eAuxiliary];}
   /// Returns the FGInput pointer.
   FGInput* GetInput(void)              {return (FGInput*)Models[eInput];}
+  /// Returns the FGOutput pointer.
+  FGOutput* GetOutput(void)            {return (FGOutput*)Models[eOutput];}
   /** Get a pointer to the ground callback currently used. It is recommanded
       to store the returned pointer in a 'smart pointer' FGGroundCallback_ptr.
       @return A pointer to the current ground callback object.
@@ -432,8 +434,8 @@ public:
   /** Forces the specified output object to print its items once */
   void ForceOutput(int idx=0) { Output->ForceOutput(idx); }
 
-  /** Sets the logging rate for all output objects (if any). */
-  void SetLoggingRate(double rate) { Output->SetRate(rate); }
+  /** Sets the logging rate in Hz for all output objects (if any). */
+  void SetLoggingRate(double rate) { Output->SetRateHz(rate); }
 
   /** Sets (or overrides) the output filename
       @param n index of file
@@ -457,12 +459,6 @@ public:
   * - tTurn
   * - tNone  */
   void DoTrim(int mode);
-  void DoSimplexTrim(int mode);
-
-  /** Executes linearization with state-space output
-   * You must trim first to get an accurate state-space model
-   */
-  void DoLinearization(int mode);
 
   /// Disables data logging to all outputs.
   void DisableOutput(void) { Output->Disable(); }
@@ -564,12 +560,17 @@ public:
       is also incremented.
       @return the new simulation time.     */
   double IncrTime(void) {
-    if (!holding) sim_time += dT;
-    GetGroundCallback()->SetTime(sim_time);
-    Frame++;
+    if (!holding && !IntegrationSuspended()) {
+      sim_time += dT;
+      GetGroundCallback()->SetTime(sim_time);
+      Frame++;
+    }
     return sim_time;
   }
 
+  /** Retrieves the current frame count. */
+  unsigned int GetFrame(void) const {return Frame;}
+
   /** Retrieves the current debug level setting. */
   int GetDebugLevel(void) const {return debug_lvl;};
 
@@ -577,6 +578,17 @@ public:
       @param FGIC The initial conditions that will be passed to the simulation. */
   void Initialize(FGInitialCondition *FGIC);
 
+  /** Sets the property forces/hold-down. This allows to do hard 'hold-down'
+      such as for rockets on a launch pad with engines ignited.
+      @param hd enables the 'hold-down' function if non-zero
+  */
+  void SetHoldDown(bool hd);
+
+  /** Gets the value of the property forces/hold-down.
+      @result zero if the 'hold-down' function is disabled, non-zero otherwise.
+  */
+  bool GetHoldDown(void) const {return HoldDown;}
+
 private:
   int Error;
   unsigned int Frame;
@@ -589,6 +601,7 @@ private:
   bool holding;
   bool IncrementThenHolding;
   int TimeStepsUntilHold;
+  int RandomSeed;
   bool Constructing;
   bool modelLoaded;
   bool IsChild;
@@ -621,6 +634,7 @@ private:
   bool trim_status;
   int ta_mode;
   unsigned int ResetMode;
+  int trim_completed;
 
   FGScript*           Script;
   FGInitialCondition* IC;
@@ -629,7 +643,9 @@ private:
   FGPropertyManager* Root;
   bool StandAlone;
   FGPropertyManager* instance;
-  
+
+  bool HoldDown;
+
   // The FDM counter is used to give each child FDM an unique ID. The root FDM has the ID 0
   unsigned int*      FDMctr;
 
@@ -641,6 +657,7 @@ private:
   bool ReadChild(Element*);
   bool ReadPrologue(Element*);
   void SRand(int sr);
+  int  SRand(void) const {return RandomSeed;}
   void LoadInputs(unsigned int idx);
   void LoadPlanetConstants(void);
   void LoadModelConstants(void);
