@@ -58,7 +58,7 @@ using namespace std;
 
 namespace JSBSim {
 
-IDENT(IdSrc,"$Id: FGInitialCondition.cpp,v 1.107 2016/01/24 18:18:38 bcoconni Exp $");
+IDENT(IdSrc,"$Id: FGInitialCondition.cpp,v 1.111 2016/07/03 17:20:55 bcoconni Exp $");
 IDENT(IdHdr,ID_INITIALCONDITION);
 
 //******************************************************************************
@@ -104,6 +104,8 @@ void FGInitialCondition::ResetIC(double u0, double v0, double w0,
   position.SetLongitude(lonRad0);
   position.SetLatitude(latRad0);
   position.SetAltitudeAGL(altAGLFt0);
+  lastLatitudeSet = setgeoc;
+  lastAltitudeSet = setagl;
 
   orientation = FGQuaternion(phi0, theta0, psi0);
   const FGMatrix33& Tb2l = orientation.GetTInv();
@@ -125,8 +127,12 @@ void FGInitialCondition::ResetIC(double u0, double v0, double w0,
 void FGInitialCondition::InitializeIC(void)
 {
   alpha=beta=0;
+  a = fdmex->GetInertial()->GetSemimajor();
+  double b = fdmex->GetInertial()->GetSemiminor();
+  double ec = b/a;
+  e2 = 1.0 - ec*ec;
 
-  position.SetEllipse(fdmex->GetInertial()->GetSemimajor(), fdmex->GetInertial()->GetSemiminor());
+  position.SetEllipse(a, b);
 
   position.SetPositionGeodetic(0.0, 0.0, 0.0);
   position.SetEarthPositionAngle(fdmex->GetPropagate()->GetEarthPositionAngle());
@@ -143,6 +149,7 @@ void FGInitialCondition::InitializeIC(void)
 
   lastSpeedSet = setvt;
   lastAltitudeSet = setasl;
+  lastLatitudeSet = setgeoc;
   enginesRunning = 0;
   needTrim = 0;
 }
@@ -696,18 +703,26 @@ void FGInitialCondition::SetAltitudeASLFtIC(double alt)
   double mach0 = vt / soundSpeed;
   double vc0 = VcalibratedFromMach(mach0, pressure, pressureSL, rhoSL);
   double ve0 = vt * sqrt(rho/rhoSL);
+  double PitotAngle = Aircraft->GetPitotAngle();
 
+  double geodLatitude = position.GetGeodLatitudeRad();
   altitudeASL=alt;
   position.SetAltitudeASL(alt);
 
+  if (lastLatitudeSet == setgeod) {
+    double h = ComputeGeodAltitude(geodLatitude);
+    position.SetPositionGeodetic(position.GetLongitude(), geodLatitude, h);
+  }
+
   soundSpeed = Atmosphere->GetSoundSpeed(altitudeASL);
   rho = Atmosphere->GetDensity(altitudeASL);
   pressure = Atmosphere->GetPressure(altitudeASL);
 
   switch(lastSpeedSet) {
     case setvc:
-      mach0 = MachFromVcalibrated(vc0, pressure, pressureSL, rhoSL);
-      SetVtrueFpsIC(mach0 * soundSpeed);
+      mach0 = MachFromVcalibrated(vc0 * cos(alpha+PitotAngle) * cos(beta),
+                                  pressure, pressureSL, rhoSL);
+      SetVtrueFpsIC(mach0 * soundSpeed / (cos(alpha+PitotAngle) * cos(beta)));
       break;
     case setmach:
       SetVtrueFpsIC(mach0 * soundSpeed);
@@ -724,10 +739,23 @@ void FGInitialCondition::SetAltitudeASLFtIC(double alt)
 
 //******************************************************************************
 
+void FGInitialCondition::SetGeodLatitudeRadIC(double geodLatitude)
+{
+  double h = ComputeGeodAltitude(geodLatitude);
+  double lon = position.GetLongitude();
+
+  position.SetPositionGeodetic(lon, geodLatitude, h);
+  lastLatitudeSet = setgeod;
+}
+
+//******************************************************************************
+
 void FGInitialCondition::SetLatitudeRadIC(double lat)
 {
   double altitude;
 
+  lastLatitudeSet = setgeoc;
+
   switch(lastAltitudeSet) {
   case setagl:
     altitude = GetAltitudeAGLFtIC();
@@ -735,9 +763,8 @@ void FGInitialCondition::SetLatitudeRadIC(double lat)
     SetAltitudeAGLFtIC(altitude);
     break;
   default:
-    altitude = position.GetAltitudeASL();
     position.SetLatitude(lat);
-    position.SetAltitudeASL(altitude);
+    break;
   }
 }
 
@@ -903,6 +930,68 @@ bool FGInitialCondition::Load(string rstfile, bool useStoredPath)
   return result;
 }
 
+//******************************************************************************
+// Given an altitude above the sea level (or a position radius which is the
+// same) and a geodetic latitude, compute the geodetic altitude. It is assumed
+// that the terrain is a sphere and that the elevation is uniform all over the
+// Earth.  Would that assumption fail, the computation below would need to be
+// adapted since the position radius would depend on the terrain elevation which
+// depends itself on the latitude.
+//
+// This is an acceptable trade off because this routine is only used by
+// standalone JSBSim which uses FGDefaultGroundCallback which assumes that the
+// Earth is a sphere.
+
+double FGInitialCondition::ComputeGeodAltitude(double geodLatitude)
+{
+  double R = position.GetRadius();
+  double slat = sin(geodLatitude);
+  double RN = a / sqrt(1.0 - e2*slat*slat);
+  double p1 = e2*RN*slat*slat;
+  double p2 = e2*e2*RN*RN*slat*slat-R*R;
+  return p1 + sqrt(p1*p1-p2) - RN;
+}
+
+//******************************************************************************
+
+bool FGInitialCondition::LoadLatitude(Element* position_el)
+{
+  Element* latitude_el = position_el->FindElement("latitude");
+
+  if (latitude_el) {
+    double latitude = position_el->FindElementValueAsNumberConvertTo("latitude", "RAD");
+
+    if (fabs(latitude) > 0.5*M_PI) {
+      string unit_type = latitude_el->GetAttributeValue("unit");
+      if (unit_type.empty()) unit_type="RAD";
+
+      cerr << latitude_el->ReadFrom() << "The latitude value "
+           << latitude_el->GetDataAsNumber() << " " << unit_type
+           << " is outside the range [";
+      if (unit_type == "DEG")
+        cerr << "-90 DEG ; +90 DEG]" << endl;
+      else
+        cerr << "-PI/2 RAD; +PI/2 RAD]" << endl;
+
+      return false;
+    }
+
+    string lat_type = latitude_el->GetAttributeValue("type");
+
+    if (lat_type == "geod" || lat_type == "geodetic") {
+      double h = ComputeGeodAltitude(latitude);
+      position.SetPositionGeodetic(position.GetLongitude(), latitude, h);
+      lastLatitudeSet = setgeod;
+    }
+    else {
+      position.SetLatitude(latitude);
+      lastLatitudeSet = setgeoc;
+    }
+  }
+
+  return true;
+}
+
 //******************************************************************************
 
 bool FGInitialCondition::Load_v1(Element* document)
@@ -921,31 +1010,7 @@ bool FGInitialCondition::Load_v1(Element* document)
   else if (document->FindElement("altitudeMSL")) // This is feet above sea level
     SetAltitudeASLFtIC(document->FindElementValueAsNumberConvertTo("altitudeMSL", "FT"));
 
-  double altitude = GetAltitudeASLFtIC();
-  double longitude = GetLongitudeRadIC();
-
-  Element* latitude_el = document->FindElement("latitude");
-  if (latitude_el) {
-    double latitude = document->FindElementValueAsNumberConvertTo("latitude", "RAD");
-    if (fabs(latitude) > 0.5*M_PI) {
-      string unit_type = latitude_el->GetAttributeValue("unit");
-      if (unit_type.empty()) unit_type="RAD";
-      cerr << latitude_el->ReadFrom() << "The latitude value "
-           << latitude_el->GetDataAsNumber() << " " << unit_type
-           << " is outside the range [";
-      if (unit_type == "DEG")
-        cerr << "-90 DEG ; +90 DEG]" << endl;
-      else
-        cerr << "-PI/2 RAD; +PI/2 RAD]" << endl;
-      result = false;
-    }
-
-    string lat_type = latitude_el->GetAttributeValue("type");
-    if (lat_type == "geod" || lat_type == "geodetic")
-      position.SetPositionGeodetic(longitude, latitude, altitude); // Longitude and altitude will be set later on
-    else
-      position.SetLatitude(latitude);
-  }
+  result = LoadLatitude(document);
 
   FGColumnVector3 vOrient = orientation.GetEuler();
 
@@ -995,9 +1060,7 @@ bool FGInitialCondition::Load_v1(Element* document)
   if (document->FindElement("xwind"))
     SetCrossWindKtsIC(document->FindElementValueAsNumberConvertTo("xwind", "KTS"));
   if (document->FindElement("targetNlf"))
-  {
     SetTargetNlfIC(document->FindElementValueAsNumber("targetNlf"));
-  }
   if (document->FindElement("trim"))
     needTrim = document->FindElementValueAsNumber("trim");
 
@@ -1006,9 +1069,9 @@ bool FGInitialCondition::Load_v1(Element* document)
   const FGMatrix33& Tl2b = orientation.GetT();
   double radInv = 1.0 / position.GetRadius();
   FGColumnVector3 vOmegaLocal = FGColumnVector3(
-   radInv*vUVW_NED(eEast),
-  -radInv*vUVW_NED(eNorth),
-  -radInv*vUVW_NED(eEast)*position.GetTanLatitude() );
+                                                radInv*vUVW_NED(eEast),
+                                                -radInv*vUVW_NED(eNorth),
+                                                -radInv*vUVW_NED(eEast)*position.GetTanLatitude() );
 
   vPQR_body = Tl2b * vOmegaLocal;
 
@@ -1035,6 +1098,9 @@ bool FGInitialCondition::Load_v2(Element* document)
   }
   FGColumnVector3 vOmegaEarth = fdmex->GetInertial()->GetOmegaPlanet();
 
+  if (document->FindElement("elevation"))
+    fdmex->GetGroundCallback()->SetTerrainGeoCentRadius(document->FindElementValueAsNumberConvertTo("elevation", "FT")+position.GetSeaLevelRadius());
+
   // Initialize vehicle position
   //
   // Allowable frames:
@@ -1049,7 +1115,6 @@ bool FGInitialCondition::Load_v2(Element* document)
       position = position.GetTi2ec() * position_el->FindElementTripletConvertTo("FT");
     } else if (frame == "ecef") {
       if (!position_el->FindElement("x") && !position_el->FindElement("y") && !position_el->FindElement("z")) {
-        Element* latitude_el = position_el->FindElement("latitude");
         if (position_el->FindElement("longitude"))
           position.SetLongitude(position_el->FindElementValueAsNumberConvertTo("longitude", "RAD"));
 
@@ -1064,17 +1129,7 @@ bool FGInitialCondition::Load_v2(Element* document)
           result = false;
         }
 
-        double altitude = position.GetAltitudeASL();
-        double longitude = position.GetLongitude();
-
-        if (latitude_el) {
-          string lat_type = latitude_el->GetAttributeValue("type");
-          double latitude = position_el->FindElementValueAsNumberConvertTo("latitude", "RAD");
-          if (lat_type == "geod" || lat_type == "geodetic")
-            position.SetPositionGeodetic(longitude, latitude, altitude);
-          else
-            position.SetLatitude(latitude);
-        }
+        result = LoadLatitude(position_el);
 
       } else {
         position = position_el->FindElementTripletConvertTo("FT");
@@ -1088,9 +1143,6 @@ bool FGInitialCondition::Load_v2(Element* document)
     result = false;
   }
 
-  if (document->FindElement("elevation"))
-    fdmex->GetGroundCallback()->SetTerrainGeoCentRadius(document->FindElementValueAsNumberConvertTo("elevation", "FT")+position.GetSeaLevelRadius());
-
   // End of position initialization
 
   // Initialize vehicle orientation
