@@ -54,7 +54,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_INITIALCONDITION "$Id: FGInitialCondition.h,v 1.44 2016/01/10 16:35:28 bcoconni Exp $"
+#define ID_INITIALCONDITION "$Id: FGInitialCondition.h,v 1.46 2016/07/03 17:20:55 bcoconni Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -71,7 +71,8 @@ class FGPropertyManager;
 class Element;
 
 typedef enum { setvt, setvc, setve, setmach, setuvw, setned, setvg } speedset;
-typedef enum { setasl, setagl} altitudeset;
+typedef enum { setasl, setagl } altitudeset;
+typedef enum { setgeoc, setgeod } latitudeset;
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS DOCUMENTATION
@@ -219,7 +220,7 @@ CLASS DOCUMENTATION
    @property ic/r-rad_sec (read/write) Yaw rate initial condition in radians/second
 
    @author Tony Peden
-   @version "$Id: FGInitialCondition.h,v 1.44 2016/01/10 16:35:28 bcoconni Exp $"
+   @version "$Id: FGInitialCondition.h,v 1.46 2016/07/03 17:20:55 bcoconni Exp $"
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -591,6 +592,12 @@ public:
       @param lat Initial latitude in radians */
   void SetLatitudeRadIC(double lat);
 
+  /** Sets the initial geodetic latitude.
+      This method modifies the geodetic altitude in order to keep the altitude
+      above sea level unchanged.
+      @param glat Initial geodetic latitude in radians */
+  void SetGeodLatitudeRadIC(double glat);
+
   /** Sets the initial longitude.
       @param lon Initial longitude in radians */
   void SetLongitudeRadIC(double lon);
@@ -677,9 +684,11 @@ private:
 
   FGMatrix33 Tw2b, Tb2w;
   double  alpha, beta;
+  double a, e2;
 
   speedset lastSpeedSet;
   altitudeset lastAltitudeSet;
+  latitudeset lastLatitudeSet;
   unsigned int enginesRunning;
   int needTrim;
 
@@ -699,6 +708,8 @@ private:
   double GetBodyVelFpsIC(int idx) const;
   void calcAeroAngles(const FGColumnVector3& _vt_BODY);
   void calcThetaBeta(double alfa, const FGColumnVector3& _vt_NED);
+  double ComputeGeodAltitude(double geodLatitude);
+  bool LoadLatitude(Element* position_el);
   void Debug(int from);
 };
 }
