@@ -57,7 +57,7 @@ using namespace std;
 
 namespace JSBSim {
 
-IDENT(IdSrc,"$Id: FGTrim.cpp,v 1.30 2015/12/29 13:44:39 ehofman Exp $");
+IDENT(IdSrc,"$Id: FGTrim.cpp,v 1.34 2016/06/12 09:09:02 bcoconni Exp $");
 IDENT(IdHdr,ID_TRIM);
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -198,9 +198,8 @@ bool FGTrim::DoTrim(void) {
   double rudder0 = FCS->GetDrCmd();
   double PitchTrim0 = FCS->GetPitchTrimCmd();
 
-  for(int i=0;i < fdmex->GetGroundReactions()->GetNumGearUnits();i++){
+  for(int i=0;i < fdmex->GetGroundReactions()->GetNumGearUnits();i++)
     fdmex->GetGroundReactions()->GetGearUnit(i)->SetReport(false);
-  }
 
   fdmex->SetTrimStatus(true);
   fdmex->SuspendIntegration();
@@ -340,12 +339,12 @@ bool FGTrim::DoTrim(void) {
         cout << endl << "  Trim failed" << endl;
   }
 
+  fdmex->GetPropagate()->InitializeDerivatives();
   fdmex->ResumeIntegration();
   fdmex->SetTrimStatus(false);
 
-  for(int i=0;i < fdmex->GetGroundReactions()->GetNumGearUnits();i++){
+  for(int i=0;i < fdmex->GetGroundReactions()->GetNumGearUnits();i++)
     fdmex->GetGroundReactions()->GetGearUnit(i)->SetReport(true);
-  }
 
   return !trim_failed;
 }
@@ -383,18 +382,22 @@ void FGTrim::trimOnGround(void)
   vector<ContactPoints> contacts;
   FGLocation CGLocation = Propagate->GetLocation();
   FGMatrix33 Tec2b = Propagate->GetTec2b();
-  FGMatrix33 Tl2b = Propagate->GetTl2b();
+  FGMatrix33 Tb2l = Propagate->GetTb2l();
   double hmin = 1E+10;
   int contactRef = -1;
 
   // Build the list of the aircraft contact points and take opportunity of the
   // loop to find which one is closer to (or deeper into) the ground.
-  for (int i = 0; i < GroundReactions->GetNumGearUnits(); i++) {
+  for (int i = 0; i < GroundReactions->GetNumGearUnits(); ++i) {
     ContactPoints c;
     FGLGear* gear = GroundReactions->GetGearUnit(i);
-    c.location = gear->GetLocalGear();
-    FGLocation gearLoc = CGLocation.LocalToLocation(c.location);
-    c.location = Tl2b * c.location;
+
+    // Skip the retracted landing gears
+    if (!gear->GetGearUnitDown())
+      continue;
+
+    c.location = gear->GetBodyLocation();
+    FGLocation gearLoc = CGLocation.LocalToLocation(Tb2l * c.location);
 
     FGColumnVector3 normal, vDummy;
     FGLocation lDummy;
@@ -405,7 +408,7 @@ void FGTrim::trimOnGround(void)
 
     if (height < hmin) {
       hmin = height;
-      contactRef = i;
+      contactRef = contacts.size() - 1;
     }
   }
 
@@ -437,7 +440,7 @@ void FGTrim::trimOnGround(void)
   // Apply the computed rotation to all the contact points
   FGMatrix33 rot = q0.GetTInv();
   vector<ContactPoints>::iterator iter;
-  for (iter = contacts.begin(); iter != contacts.end(); iter++)
+  for (iter = contacts.begin(); iter != contacts.end(); ++iter)
     iter->location = contact0 + rot * (iter->location - contact0);
 
   // Remove the second point to come in contact with the ground from the list.
@@ -461,7 +464,7 @@ void FGTrim::trimOnGround(void)
   FGQuaternion q1(rParam.angleMin, rotationAxis);
 
   // Update the aircraft orientation
-  FGColumnVector3 euler = (q0 * q1 * fgic.GetOrientation()).GetEuler();
+  FGColumnVector3 euler = (fgic.GetOrientation() * q0 * q1).GetEuler();
 
   fgic.SetPhiRadIC(euler(1));
   fgic.SetThetaRadIC(euler(2));
@@ -486,7 +489,7 @@ FGTrim::RotationParameters FGTrim::calcRotation(vector<ContactPoints>& contacts,
 
   rParam.angleMin = 3.0 * M_PI;
 
-  for (iter = contacts.begin(); iter != contacts.end(); iter++) {
+  for (iter = contacts.begin(); iter != contacts.end(); ++iter) {
     // Below the processed contact point is named 'M'
     // Construct an orthonormal basis (u, v, t). The ground normal is obtained
     // from iter->normal.
