@@ -48,14 +48,12 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_MASSBALANCE "$Id: FGMassBalance.h,v 1.32 2014/11/29 13:47:19 bcoconni Exp $"
+#define ID_MASSBALANCE "$Id: FGMassBalance.h,v 1.37 2016/03/26 18:54:27 bcoconni Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONSS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-using std::string;
-
 namespace JSBSim {
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -204,7 +202,12 @@ private:
   FGColumnVector3 vPMxyz;
   FGColumnVector3 PointMassCG;
   const FGMatrix33& CalculatePMInertias(void);
-
+  double GetIxx(void) const { return mJ(1,1); }
+  double GetIyy(void) const { return mJ(2,2); }
+  double GetIzz(void) const { return mJ(3,3); }
+  double GetIxy(void) const { return -mJ(1,2); }
+  double GetIxz(void) const { return -mJ(1,3); }
+  double GetIyz(void) const { return -mJ(2,3); }
 
   /** The PointMass structure encapsulates a point mass object, moments of inertia
      mass, location, etc. */
@@ -248,7 +251,7 @@ private:
     double Weight; /// Weight in pounds.
     double Radius; /// Radius in feet.
     double Length; /// Length in feet.
-    string Name;
+    std::string Name;
     FGMatrix33 mPMInertia;
 
     double GetPointMassLocation(int axis) const {return Location(axis);}
@@ -256,7 +259,7 @@ private:
     esShape GetShapeType(void) {return eShapeType;}
     const FGColumnVector3& GetLocation(void) {return Location;}
     const FGMatrix33& GetPointMassInertia(void) {return mPMInertia;}
-    const string& GetName(void) {return Name;}
+    const std::string& GetName(void) {return Name;}
 
     void SetPointMassLocation(int axis, double value) {Location(axis) = value;}
     void SetPointMassWeight(double wt) {
@@ -266,11 +269,11 @@ private:
     void SetPointMassShapeType(esShape st) {eShapeType = st;}
     void SetRadius(double r) {Radius = r;}
     void SetLength(double l) {Length = l;}
-    void SetName(string name) {Name = name;}
+    void SetName(const std::string& name) {Name = name;}
     void SetPointMassMoI(const FGMatrix33& MoI) { mPMInertia = MoI; }
     double GetPointMassMoI(int r, int c) {return mPMInertia(r,c);}
 
-    void bind(FGPropertyManager* PropertyManager, int num);
+    void bind(FGPropertyManager* PropertyManager, unsigned int num);
   };
 
   std::vector <struct PointMass*> PointMasses;
