@@ -5,6 +5,7 @@
 
 #include <simgear/props/props.hxx>
 #include <simgear/xml/easyxml.hxx>
+#include <simgear/misc/sg_path.hxx>
 
 #include "FGFDM.hpp"
 #include "Atmosphere.hpp"
@@ -83,7 +84,7 @@ int main(int argc, char** argv)
     // Read
     try {
         string file = argv[1];
-        readXML(file, *fdm);
+        readXML(SGPath(file), *fdm);
     } catch (const sg_exception &e) {
         printf("XML parse error: %s (%s)\n",
                e.getFormattedMessage().c_str(), e.getOrigin());
