@@ -346,7 +346,7 @@ protected:
     virtual void catalogRefreshed(CatalogRef aCatalog, StatusCode aReason)
     {
         if (aReason == STATUS_IN_PROGRESS) {
-            qDebug() << "doing refresh of" << QString::fromStdString(aCatalog->url());
+            // nothing to do
         } else if ((aReason == STATUS_REFRESHED) || (aReason == STATUS_SUCCESS)) {
             m_model->refreshPackages();
         } else {
@@ -402,19 +402,16 @@ protected:
         if (pix.height() > STANDARD_THUMBNAIL_HEIGHT) {
             pix = pix.scaledToHeight(STANDARD_THUMBNAIL_HEIGHT);
         }
-        m_model->m_thumbnailPixmapCache.insert(QString::fromStdString(aThumbnailUrl),
-                                               pix);
+        m_model->m_thumbnailPixmapCache.insert(QString::fromStdString(aThumbnailUrl), pix);
 
         // notify any affected items. Linear scan here avoids another map/dict
         // structure.
-        PackageList::const_iterator it;
-        int i = 0;
-
-        for (it=m_model->m_packages.begin(); it != m_model->m_packages.end(); ++it, ++i) {
+        for (auto it=m_model->m_packages.begin(); it != m_model->m_packages.end(); ++it) {
             const string_list& urls((*it)->thumbnailUrls());
-            string_list::const_iterator cit = std::find(urls.begin(), urls.end(), aThumbnailUrl);
+            auto cit = std::find(urls.begin(), urls.end(), aThumbnailUrl);
             if (cit != urls.end()) {
-                QModelIndex mi(m_model->index(i + m_model->m_items.size()));
+                size_t offset = it - m_model->m_packages.begin();
+                QModelIndex mi(m_model->index(offset + m_model->m_items.size()));
                 m_model->dataChanged(mi, mi);
             }
         } // of packages iteration
@@ -423,9 +420,8 @@ protected:
 private:
     QModelIndex indexForPackage(const PackageRef& ref) const
     {
-        PackageList::const_iterator it = std::find(m_model->m_packages.begin(),
-                                                   m_model->m_packages.end(),
-                                                   ref);
+        auto it = std::find(m_model->m_packages.begin(),
+                            m_model->m_packages.end(), ref);
         if (it == m_model->m_packages.end()) {
             return QModelIndex();
         }
@@ -438,9 +434,7 @@ private:
 };
 
 AircraftItemModel::AircraftItemModel(QObject* pr ) :
-    QAbstractListModel(pr),
-    m_scanThread(NULL),
-    m_showOfficialHangarMessage(false)
+    QAbstractListModel(pr)
 {
 }
 
@@ -471,30 +465,30 @@ void AircraftItemModel::setPaths(QStringList paths)
     m_paths = paths;
 }
 
-void AircraftItemModel::setOfficialHangarMessageVisible(bool vis)
+void AircraftItemModel::setMessageWidgetVisible(bool vis)
 {
-    if (m_showOfficialHangarMessage == vis) {
+    if (m_showMessageWidget == vis) {
         return;
     }
 
-    m_showOfficialHangarMessage = vis;
+    m_showMessageWidget = vis;
 
     if (vis) {
         beginInsertRows(QModelIndex(), 0, 0);
         m_items.prepend(AircraftItemPtr(new AircraftItem));
-        m_activeVariant.prepend(0);
+        m_delegateStates.prepend(DelegateState());
         endInsertRows();
     } else {
         beginRemoveRows(QModelIndex(), 0, 0);
         m_items.removeAt(0);
-        m_activeVariant.removeAt(0);
+        m_delegateStates.removeAt(0);
         endRemoveRows();
     }
 }
 
-QModelIndex AircraftItemModel::officialHangarMessageIndex() const
+QModelIndex AircraftItemModel::messageWidgetIndex() const
 {
-    if (!m_showOfficialHangarMessage) {
+    if (!m_showMessageWidget) {
         return QModelIndex();
     }
 
@@ -503,26 +497,28 @@ QModelIndex AircraftItemModel::officialHangarMessageIndex() const
 
 void AircraftItemModel::scanDirs()
 {
-    abandonCurrentScan();
+	abandonCurrentScan();
 
-    int firstRow = (m_showOfficialHangarMessage ? 1 : 0);
-    int numToRemove = m_items.size() - firstRow;
-    int lastRow = firstRow + numToRemove - 1;
+    int firstRow = (m_showMessageWidget ? 1 : 0);
+	int numToRemove = m_items.size() - firstRow;
+	if (numToRemove > 0) {
+		int lastRow = firstRow + numToRemove - 1;
 
-    beginRemoveRows(QModelIndex(), firstRow, lastRow);
-    m_items.remove(firstRow, numToRemove);
-    m_activeVariant.remove(firstRow, numToRemove);
-    endRemoveRows();
+		beginRemoveRows(QModelIndex(), firstRow, lastRow);
+		m_items.remove(firstRow, numToRemove);
+		m_delegateStates.remove(firstRow, numToRemove);
+		endRemoveRows();
+	}
 
     QStringList dirs = m_paths;
 
-    Q_FOREACH(std::string ap, globals->get_aircraft_paths()) {
-        dirs << QString::fromStdString(ap);
+    Q_FOREACH(SGPath ap, globals->get_aircraft_paths()) {
+        dirs << QString::fromStdString(ap.utf8Str());
     }
 
     SGPath rootAircraft(globals->get_fg_root());
     rootAircraft.append("Aircraft");
-    dirs << QString::fromStdString(rootAircraft.str());
+    dirs << QString::fromStdString(rootAircraft.utf8Str());
 
     m_scanThread = new AircraftScanThread(dirs);
     connect(m_scanThread, &AircraftScanThread::finished, this,
@@ -545,8 +541,9 @@ void AircraftItemModel::abandonCurrentScan()
 void AircraftItemModel::refreshPackages()
 {
     simgear::pkg::PackageList newPkgs = m_packageRoot->allPackages();
-    int firstRow = m_items.size();
-    int newSize = newPkgs.size();
+    const int firstRow = m_items.size();
+    const int newSize = newPkgs.size();
+    const int newTotalSize = firstRow + newSize;
 
     if (m_packages.size() != newPkgs.size()) {
         int oldSize = m_packages.size();
@@ -556,7 +553,7 @@ void AircraftItemModel::refreshPackages()
             int lastNewRow = firstRow + newSize - 1;
             beginInsertRows(QModelIndex(), firstNewRow, lastNewRow);
             m_packages = newPkgs;
-            m_packageVariant.resize(newSize);
+            m_delegateStates.resize(newTotalSize);
             endInsertRows();
         } else {
             // shrinking
@@ -564,7 +561,7 @@ void AircraftItemModel::refreshPackages()
             int lastOldRow = firstRow + oldSize - 1;
             beginRemoveRows(QModelIndex(), firstOldRow, lastOldRow);
             m_packages = newPkgs;
-            m_packageVariant.resize(newSize);
+            m_delegateStates.resize(newTotalSize);
             endRemoveRows();
         }
     } else {
@@ -572,6 +569,7 @@ void AircraftItemModel::refreshPackages()
     }
 
     emit dataChanged(index(firstRow), index(firstRow + newSize - 1));
+    emit packagesNeedUpdating(!m_packageRoot->packagesNeedingUpdate().empty());
 }
 
 int AircraftItemModel::rowCount(const QModelIndex& parent) const
@@ -582,23 +580,26 @@ int AircraftItemModel::rowCount(const QModelIndex& parent) const
 QVariant AircraftItemModel::data(const QModelIndex& index, int role) const
 {
     int row = index.row();
-    if (m_showOfficialHangarMessage) {
+    if (m_showMessageWidget) {
         if (row == 0) {
             if (role == AircraftPackageStatusRole) {
-                return NoOfficialCatalogMessage;
+                return MessageWidget;
             }
 
             return QVariant();
         }
     }
 
+    if (role == AircraftVariantRole) {
+        return m_delegateStates.at(row).variant;
+    }
+
+    if (role == AircraftCurrentThumbnailRole) {
+        return m_delegateStates.at(row).thumbnail;
+    }
+
     if (row >= m_items.size()) {
         quint32 packageIndex = row - m_items.size();
-
-        if (role == AircraftVariantRole) {
-            return m_packageVariant.at(packageIndex);
-        }
-
         const PackageRef& pkg(m_packages[packageIndex]);
         InstallRef ex = pkg->existingInstall();
 
@@ -608,20 +609,14 @@ QVariant AircraftItemModel::data(const QModelIndex& index, int role) const
             return static_cast<quint64>(ex.valid() ? ex->downloadedBytes() : 0);
         }
 
-        quint32 variantIndex = m_packageVariant.at(packageIndex);
-        return dataFromPackage(pkg, variantIndex, role);
+        return dataFromPackage(pkg, m_delegateStates.at(row), role);
     } else {
-        if (role == AircraftVariantRole) {
-            return m_activeVariant.at(row);
-        }
-
-        quint32 variantIndex = m_activeVariant.at(row);
         const AircraftItemPtr item(m_items.at(row));
-        return dataFromItem(item, variantIndex, role);
+        return dataFromItem(item, m_delegateStates.at(row), role);
     }
 }
 
-QVariant AircraftItemModel::dataFromItem(AircraftItemPtr item, quint32 variantIndex, int role) const
+QVariant AircraftItemModel::dataFromItem(AircraftItemPtr item, const DelegateState& state, int role) const
 {
     if (role == AircraftVariantCountRole) {
         return item->variants.count();
@@ -641,10 +636,10 @@ QVariant AircraftItemModel::dataFromItem(AircraftItemPtr item, quint32 variantIn
         return item->variants.at(variantIndex)->description;
     }
 
-    if (variantIndex) {
-        if (variantIndex <= static_cast<quint32>(item->variants.count())) {
+    if (state.variant) {
+        if (state.variant <= static_cast<quint32>(item->variants.count())) {
             // show the selected variant
-            item = item->variants.at(variantIndex - 1);
+            item = item->variants.at(state.variant - 1);
         }
     }
 
@@ -689,7 +684,7 @@ QVariant AircraftItemModel::dataFromItem(AircraftItemPtr item, quint32 variantIn
     return QVariant();
 }
 
-QVariant AircraftItemModel::dataFromPackage(const PackageRef& item, quint32 variantIndex, int role) const
+QVariant AircraftItemModel::dataFromPackage(const PackageRef& item, const DelegateState& state, int role) const
 {
     if (role == Qt::DecorationRole) {
         role = AircraftThumbnailRole; // use first thumbnail
@@ -705,7 +700,7 @@ QVariant AircraftItemModel::dataFromPackage(const PackageRef& item, quint32 vari
     }
 
     if (role == Qt::DisplayRole) {
-        QString desc = QString::fromStdString(item->nameForVariant(variantIndex));
+        QString desc = QString::fromStdString(item->nameForVariant(state.variant));
         if (desc.isEmpty()) {
             desc = tr("Missing description for: %1").arg(QString::fromStdString(item->id()));
         }
@@ -713,10 +708,10 @@ QVariant AircraftItemModel::dataFromPackage(const PackageRef& item, quint32 vari
     } else if (role == AircraftPathRole) {
         InstallRef i = item->existingInstall();
         if (i.valid()) {
-            return QString::fromStdString(i->primarySetPath().str());
+            return QString::fromStdString(i->primarySetPath().utf8Str());
         }
     } else if (role == AircraftPackageIdRole) {
-        return QString::fromStdString(item->variants()[variantIndex]);
+        return QString::fromStdString(item->variants()[state.variant]);
     } else if (role == AircraftPackageStatusRole) {
         InstallRef i = item->existingInstall();
         if (i.valid()) {
@@ -739,12 +734,15 @@ QVariant AircraftItemModel::dataFromPackage(const PackageRef& item, quint32 vari
         // including the primary. Hence the -1 term.
         return static_cast<quint32>(item->variants().size() - 1);
     } else if (role == AircraftThumbnailSizeRole) {
-        QPixmap pm = packageThumbnail(item, 0, false).value<QPixmap>();
+        QPixmap pm = packageThumbnail(item, state, false).value<QPixmap>();
         if (pm.isNull())
             return QSize(STANDARD_THUMBNAIL_WIDTH, STANDARD_THUMBNAIL_HEIGHT);
         return pm.size();
     } else if (role >= AircraftThumbnailRole) {
-        return packageThumbnail(item , role - AircraftThumbnailRole);
+        DelegateState changedState(state);
+        // override the current thumbnail as required
+        changedState.thumbnail = (role - AircraftThumbnailRole);
+        return packageThumbnail(item, changedState);
     } else if (role == AircraftAuthorsRole) {
         SGPropertyNode* authors = item->properties()->getChild("author");
         if (authors) {
@@ -755,7 +753,7 @@ QVariant AircraftItemModel::dataFromPackage(const PackageRef& item, quint32 vari
     } else if (role == AircraftPackageSizeRole) {
         return static_cast<int>(item->fileSizeBytes());
     } else if (role == AircraftURIRole) {
-        return QUrl("package:" + QString::fromStdString(item->qualifiedVariantId(variantIndex)));
+        return QUrl("package:" + QString::fromStdString(item->qualifiedVariantId(state.variant)));
     } else if (role == AircraftHasRatingsRole) {
         return item->properties()->hasChild("rating");
     } else if ((role >= AircraftRatingRole) && (role < AircraftVariantDescriptionRole)) {
@@ -770,14 +768,14 @@ QVariant AircraftItemModel::dataFromPackage(const PackageRef& item, quint32 vari
     return QVariant();
 }
 
-QVariant AircraftItemModel::packageThumbnail(PackageRef p, int index, bool download) const
+QVariant AircraftItemModel::packageThumbnail(PackageRef p, const DelegateState& ds, bool download) const
 {
     const string_list& thumbnails(p->thumbnailUrls());
-    if (index >= static_cast<int>(thumbnails.size())) {
+    if (ds.thumbnail >= static_cast<int>(thumbnails.size())) {
         return QVariant();
     }
 
-    std::string thumbnailUrl = thumbnails.at(index);
+    std::string thumbnailUrl = thumbnails.at(ds.thumbnail);
     QString urlQString(QString::fromStdString(thumbnailUrl));
     if (m_thumbnailPixmapCache.contains(urlQString)) {
         // cache hit, easy
@@ -791,10 +789,10 @@ QVariant AircraftItemModel::packageThumbnail(PackageRef p, int index, bool downl
         const string_list& thumbNames(p->thumbnails());
         if (!thumbNames.empty()) {
             SGPath path(ex->path());
-            path.append(p->thumbnails()[index]);
+            path.append(p->thumbnails()[ds.thumbnail]);
             if (path.exists()) {
                 QPixmap pix;
-                pix.load(QString::fromStdString(path.str()));
+                pix.load(QString::fromStdString(path.utf8Str()));
                 // resize to the standard size
                 if (pix.height() > STANDARD_THUMBNAIL_HEIGHT) {
                     pix = pix.scaledToHeight(STANDARD_THUMBNAIL_HEIGHT);
@@ -808,20 +806,31 @@ QVariant AircraftItemModel::packageThumbnail(PackageRef p, int index, bool downl
     if (download) {
         m_packageRoot->requestThumbnailData(thumbnailUrl);
     }
+
     return QVariant();
 }
 
 bool AircraftItemModel::setData(const QModelIndex &index, const QVariant &value, int role)
   {
       int row = index.row();
+      int newValue = value.toInt();
+
       if (role == AircraftVariantRole) {
-          if (row >= m_activeVariant.size()) {
-              row -= m_activeVariant.size();
-              m_packageVariant[row] = value.toInt();
-          } else {
-              m_activeVariant[row] = value.toInt();
+          if (m_delegateStates[row].variant == newValue) {
+              return true;
           }
 
+          m_delegateStates[row].variant = newValue;
+          emit dataChanged(index, index);
+          return true;
+      }
+
+      if (role == AircraftCurrentThumbnailRole) {
+          if (m_delegateStates[row].thumbnail == newValue) {
+              return true;
+          }
+
+          m_delegateStates[row].thumbnail = newValue;
           emit dataChanged(index, index);
           return true;
       }
@@ -871,6 +880,60 @@ QModelIndex AircraftItemModel::indexOfAircraftURI(QUrl uri) const
     return QModelIndex();
 }
 
+void AircraftItemModel::selectVariantForAircraftURI(QUrl uri)
+{
+    if (uri.isEmpty()) {
+        return;
+    }
+
+    int variantIndex = 0;
+    QModelIndex modelIndex;
+
+    if (uri.isLocalFile()) {
+        QString path = uri.toLocalFile();
+        for (int row=0; row <m_items.size(); ++row) {
+            const AircraftItemPtr item(m_items.at(row));
+            if (item->path == path) {
+                modelIndex = index(row);
+                variantIndex = 0;
+                break;
+            }
+
+            // check variants too
+            for (int vr=0; vr < item->variants.size(); ++vr) {
+                if (item->variants.at(vr)->path == path) {
+                    modelIndex = index(row);
+                    variantIndex = vr + 1;
+                    break;
+                }
+            }
+        }
+    } else if (uri.scheme() == "package") {
+        QString ident = uri.path();
+        int rowOffset = m_items.size();
+
+        PackageRef pkg = m_packageRoot->getPackageById(ident.toStdString());
+        if (pkg) {
+            for (size_t i=0; i < m_packages.size(); ++i) {
+                if (m_packages[i] == pkg) {
+                    modelIndex =  index(rowOffset + i);
+                    variantIndex = pkg->indexOfVariant(ident.toStdString());
+                    break;
+                }
+            } // of linear package scan
+        }
+    } else {
+        qWarning() << "Unknown aircraft URI scheme" << uri << uri.scheme();
+        return;
+    }
+
+    if (modelIndex.isValid()) {
+        qDebug() << "selected variant index" << variantIndex << "at" << modelIndex
+        << "for variant" << uri;
+        setData(modelIndex, variantIndex, AircraftVariantRole);
+    }
+}
+
 void AircraftItemModel::onScanResults()
 {
     QVector<AircraftItemPtr> newItems = m_scanThread->items();
@@ -884,8 +947,9 @@ void AircraftItemModel::onScanResults()
 
     // default variants in all cases
     for (int i=0; i< newItems.count(); ++i) {
-        m_activeVariant.append(0);
+        m_delegateStates.insert(firstRow + i, DelegateState());
     }
+
     endInsertRows();
 }
 
