@@ -80,9 +80,16 @@ static double distanceToLineSegment(const QVector2D& p, const QVector2D& a,
     return 0.0;
 }
 
+static double unitLengthAfterMapping(const QTransform& t)
+{
+    const QPointF tVec = t.map(QPointF(1.0, 0.0)) - t.map(QPointF(0.0, 0.0));
+    return QVector2D(tVec).length();
+}
+
 AirportDiagram::AirportDiagram(QWidget* pr) :
     BaseDiagram(pr),
-    m_approachDistanceNm(-1.0)
+    m_approachDistanceNm(-1.0),
+    m_helipadIcon(":/heliport-icon")
 {
     m_parkingIconPath.moveTo(0,0);
     m_parkingIconPath.lineTo(-16, -16);
@@ -109,8 +116,7 @@ void AirportDiagram::setAirport(FGAirportRef apt)
     m_airport = apt;
     m_projectionCenter = apt ? apt->geod() : SGGeod();
     m_runways.clear();
-    m_approachDistanceNm = -1.0;
-    m_parking.clear();
+    m_approachDistanceNm = -1.0;    m_parking.clear();
     m_helipads.clear();
 
     if (apt) {
@@ -135,18 +141,34 @@ void AirportDiagram::setSelectedRunway(FGRunwayRef r)
     if (r == m_selectedRunway) {
         return;
     }
-    
+
+    m_selectedParking.clear();
     m_selectedRunway = r;
     update();
 }
 
 void AirportDiagram::setSelectedHelipad(FGHelipadRef pad)
 {
+    qWarning() << Q_FUNC_INFO << "implement me";
+}
 
+void AirportDiagram::setSelectedParking(FGParkingRef park)
+{
+    if (m_selectedParking == park) {
+        return;
+    }
+
+    m_selectedRunway.clear();
+    m_selectedParking = park;
+    update();
 }
 
 void AirportDiagram::setApproachExtensionDistance(double distanceNm)
 {
+    if (m_approachDistanceNm == distanceNm) {
+        return;
+    }
+
     m_approachDistanceNm = distanceNm;
     recomputeBounds(true);
     update();
@@ -319,63 +341,118 @@ void AirportDiagram::paintContents(QPainter* p)
         p->setTransform(t);
         paintAirplaneIcon(p, aircraftPos, headingDeg);
     }
+
+ #if 0
+    p->resetTransform();
+    QPen testPen(Qt::cyan);
+    testPen.setWidth(1);
+    testPen.setCosmetic(true);
+    p->setPen(testPen);
+    p->setBrush(Qt::NoBrush);
+
+    double minWidth = 8.0 * unitLengthAfterMapping(t.inverted());
+
+    Q_FOREACH(const RunwayData& r, m_runways) {
+        QPainterPath pp = pathForRunway(r, t, minWidth);
+        p->drawPath(pp);
+    } // of runways iteration
+#endif
 }
 
 void AirportDiagram::drawHelipads(QPainter* painter)
 {
     QTransform t = painter->transform();
-    QPixmap icon(":/heliport-icon");
 
-    QRect r = icon.rect();
+    QRect r = m_helipadIcon.rect();
     r.moveCenter(QPoint(0, 0));
 
     Q_FOREACH(const HelipadData& p, m_helipads) {
         painter->setTransform(t);
         painter->translate(p.pt);
-        painter->drawPixmap(r, icon);
+        painter->drawPixmap(r, m_helipadIcon);
     }
 }
 
-void AirportDiagram::drawParkings(QPainter* painter)
+void AirportDiagram::drawParking(QPainter* painter, const ParkingData& p) const
 {
-    QTransform t = painter->transform();
+    painter->translate(p.pt);
 
+    double hdg = p.parking->getHeading();
+    bool useLeftIcon = false;
+    QRect labelRect(-62, -14, 40, 28);
 
-    QFont f = painter->font();
-    f.setPixelSize(16);
-    painter->setFont(f);
-
-    Q_FOREACH(const ParkingData& p, m_parking) {
-        painter->setTransform(t);
-        painter->translate(p.pt);
-
-        double hdg = p.parking->getHeading();
-        bool useLeftIcon = false;
-        QRect labelRect(-62, -14, 40, 28);
-
-        if (hdg > 180.0) {
-            hdg += 90;
-            useLeftIcon = true;
-            labelRect = QRect(22, -14, 40, 28);
-        } else {
-            hdg -= 90;
-        }
-
-        painter->rotate(hdg);
-
-        painter->setBrush(QColor(255, 196, 196)); // kind of pink
-        painter->drawPath(useLeftIcon ? m_parkingIconLeftPath : m_parkingIconPath);
-
-        painter->fillRect(labelRect, Qt::white);
-
-        // draw text
-        painter->setPen(Qt::black);
-        painter->drawText(labelRect,
-                          Qt::AlignVCenter | Qt::AlignHCenter,
-                          QString::fromStdString(p.parking->name()));
+    if (hdg > 180.0) {
+        hdg += 90;
+        useLeftIcon = true;
+        labelRect = QRect(22, -14, 40, 28);
+    } else {
+        hdg -= 90;
     }
 
-    painter->setTransform(t);
+    painter->rotate(hdg);
+
+    if (p.parking == m_selectedParking) {
+        painter->setBrush(Qt::yellow);
+    } else {
+        painter->setBrush(QColor(255, 196, 196)); // kind of pink
+    }
+
+    painter->drawPath(useLeftIcon ? m_parkingIconLeftPath : m_parkingIconPath);
+
+    // ensure the selection colour is quite visible, by not filling
+    // with white when selected
+    if (p.parking != m_selectedParking) {
+        painter->fillRect(labelRect, Qt::white);
+    }
+
+    QFont f = painter->font();
+    f.setPixelSize(20);
+    painter->setFont(f);
+
+    QString parkingName = QString::fromStdString(p.parking->name());
+    int textFlags = Qt::AlignVCenter | Qt::AlignHCenter | Qt::TextWordWrap;
+    QRectF bounds = painter->boundingRect(labelRect, textFlags, parkingName);
+    if (bounds.height() > labelRect.height()) {
+        f.setPixelSize(10);
+        painter->setFont(f);
+    }
+
+    // draw text
+    painter->setPen(Qt::black);
+    painter->drawText(labelRect, textFlags, parkingName);
+}
+
+AirportDiagram::ParkingData AirportDiagram::findParkingData(const FGParkingRef &pk) const
+{
+    Q_FOREACH(const ParkingData& p, m_parking) {
+        if (p.parking == m_selectedParking) {
+            return p;
+        }
+    }
+
+    return ParkingData();
+}
+
+void AirportDiagram::drawParkings(QPainter* painter) const
+{
+    painter->save();
+    QTransform t = painter->transform();
+
+    Q_FOREACH(const ParkingData& p, m_parking) {
+        if (p.parking == m_selectedParking) {
+            continue; // skip and draw last
+        }
+
+        painter->setTransform(t);
+        drawParking(painter, p);
+    }
+
+    if (m_selectedParking) {
+        painter->setTransform(t);
+        drawParking(painter, findParkingData(m_selectedParking));
+    }
+
+    painter->restore();
 }
 
 void AirportDiagram::drawILS(QPainter* painter, FGRunwayRef runway) const
@@ -405,67 +482,92 @@ void AirportDiagram::drawILS(QPainter* painter, FGRunwayRef runway) const
     painter->drawLine(endR, endCentre);
 }
 
-static double pointDistance(const QPointF& p1, const QPointF& p2)
-{
-    QPointF d = p2 - p1;
-    return ::sqrt((d.x() * d.x()) + (d.y() * d.y()));
-}
-
 void AirportDiagram::mouseReleaseEvent(QMouseEvent* me)
 {
-    if (m_didPan)
-        return; // ignore panning drag+release ops here
-
-    QTransform t(transform());
-    double minDist = std::numeric_limits<double>::max();
-    FGRunwayRef bestRunway;
-    FGHelipadRef bestHelipad;
-    FGParkingRef bestParking;
-
-    Q_FOREACH(const RunwayData& r, m_runways) {
-        QPointF p1(t.map(r.p1)), p2(t.map(r.p2));
-        double t;
-        double d = distanceToLineSegment(QVector2D(me->pos()),
-                                         QVector2D(p1),
-                                         QVector2D(p2), &t);
-        if (d < minDist) {
-            if (t > 0.5) {
-                bestRunway = r.runway->reciprocalRunway();
-            } else {
-                bestRunway = r.runway;
-            }
-            minDist = d;
-        }
+    if (me->button() != Qt::LeftButton) {
+        return;
     }
 
+    QTransform t(transform());
+    double minWidth = 8.0 * unitLengthAfterMapping(t.inverted());
+
+    Q_FOREACH(const RunwayData& r, m_runways) {
+        QPainterPath pp = pathForRunway(r, t, minWidth);
+        if (pp.contains(me->pos())) {
+            // check which end was clicked
+            QPointF p1(t.map(r.p1)), p2(t.map(r.p2));
+            double param;
+            distanceToLineSegment(QVector2D(me->pos()), QVector2D(p1), QVector2D(p2), &param);
+            if (param > 0.5) {
+                emit clickedRunway(r.runway->reciprocalRunway());
+            } else {
+                emit clickedRunway(r.runway);
+            }
+            return;
+        }
+    } // of runways iteration
+
     Q_FOREACH(const ParkingData& parking, m_parking) {
-        double d = pointDistance(me->pos(), t.map(parking.pt));
-        if (d < minDist) {
-            bestParking = parking.parking;
-            bestRunway.clear();
-            minDist = d;
+        QPainterPath pp = pathForParking(parking, t);
+        if (pp.contains(me->pos())) {
+            emit clickedParking(parking.parking);
+            return;
         }
     }
 
     Q_FOREACH(const HelipadData& pad, m_helipads) {
-        double d = pointDistance(me->pos(), t.map(pad.pt));
-        if (d < minDist) {
-            bestHelipad = pad.helipad;
-            bestRunway.clear();
-            bestParking.clear();
-            minDist = d;
+        QPainterPath pp = pathForHelipad(pad, t);
+        if (pp.contains(me->pos())) {
+            emit clickedHelipad(pad.helipad);
+            return;
         }
     }
+}
 
-    
-    if (minDist < 16.0) {
-        if (bestRunway)
-            emit clickedRunway(bestRunway);
-        else if (bestParking)
-            emit clickedParking(bestParking);
-        else if (bestHelipad)
-            emit clickedHelipad(bestHelipad);
+QPainterPath AirportDiagram::pathForRunway(const RunwayData& r, const QTransform& t,
+                                           const double minWidth) const
+{
+    QPainterPath pp;
+    double width = qMax(static_cast<double>(r.widthM), minWidth);
+    double halfWidth = width * 0.5;
+    QVector2D v = QVector2D(r.p2 - r.p1);
+    v.normalize();
+    QVector2D halfVec = QVector2D(v.y(), -v.x()) * halfWidth;
+
+    pp.moveTo(r.p1 - halfVec.toPointF());
+    pp.lineTo(r.p1 + halfVec.toPointF());
+    pp.lineTo(r.p2 + halfVec.toPointF());
+    pp.lineTo(r.p2 - halfVec.toPointF());
+    pp.closeSubpath();
+
+    return t.map(pp);
+}
+
+QPainterPath AirportDiagram::pathForParking(const ParkingData& p, const QTransform& t) const
+{
+    bool useLeftIcon = false;
+    double hdg = p.parking->getHeading();
+
+    if (hdg > 180.0) {
+        hdg += 90;
+        useLeftIcon = true;
+    } else {
+        hdg -= 90;
     }
+
+    QTransform x = t;
+    x.translate(p.pt.x(), p.pt.y());
+    x.rotate(hdg);
+    return x.map(useLeftIcon ? m_parkingIconLeftPath : m_parkingIconPath);
+}
+
+QPainterPath AirportDiagram::pathForHelipad(const HelipadData& h, const QTransform& t) const
+{
+    QPainterPath pp;
+    QRect r = m_helipadIcon.rect();
+    r.moveCenter(QPoint(0, 0));
+    pp.addEllipse(r);
+    return t.map(pp);
 }
 
 void AirportDiagram::buildTaxiways()
