@@ -52,7 +52,7 @@ std::string stdStringFromCocoa(NSString* s)
 
 NSURL* pathToNSURL(const SGPath& aPath)
 {
-    return [NSURL fileURLWithPath:stdStringToCocoa(aPath.str())];
+    return [NSURL fileURLWithPath:stdStringToCocoa(aPath.utf8Str())];
 }
 
 SGPath URLToPath(NSURL* url)
@@ -133,14 +133,14 @@ SGPath platformDefaultDataPath()
 namespace flightgear
 {
     
-std::string Options::platformDefaultRoot() const
+SGPath Options::platformDefaultRoot() const
 {
     CocoaAutoreleasePool ap;
     
     NSURL* url = [[NSBundle mainBundle] resourceURL];
     SGPath dataDir(URLToPath(url));
     dataDir.append("data");
-    return dataDir.str();
+    return dataDir;
 }
     
 } // of namespace flightgear
