@@ -6,8 +6,10 @@
 
 #include "MessageBox.hxx"
 
+#include <Main/fg_props.hxx>
 #include <Main/globals.hxx>
 #include <Viewer/renderer.hxx>
+#include <GUI/new_gui.hxx>
 
 #include <osgViewer/Viewer>
 
@@ -64,15 +66,15 @@ HWND getMainViewerHWND()
         if (strcmp((*it)->className(), "GraphicsWindowWin32")) {
             continue;
         }
-        
-        osgViewer::GraphicsWindowWin32* platformWin = 
+
+        osgViewer::GraphicsWindowWin32* platformWin =
             static_cast<osgViewer::GraphicsWindowWin32*>(*it);
         return platformWin->getHWND();
     }
-    
+
     return 0;
 }
-    
+
 flightgear::MessageBoxResult
 win32MessageBox(const std::string& caption,
                     const std::string& msg,
@@ -85,26 +87,24 @@ win32MessageBox(const std::string& caption,
     if (!moreText.empty()) {
         fullMsg += "\n\n" + moreText;
     }
-    
-    UINT mbType = MB_OK;
-	WCharVec wMsg(convertUtf8ToWString(fullMsg)),
-		wCap(convertUtf8ToWString(caption));
-	wMsg.push_back(0);
-	wCap.push_back(0);
 
-	::MessageBoxExW(ownerWindow, wMsg.data(), wCap.data(),
+    UINT mbType = MB_OK;
+	std::wstring wMsg(convertUtf8ToWString(fullMsg)),
+		wCap(convertUtf8ToWString(caption));
+
+	::MessageBoxExW(ownerWindow, wMsg.c_str(), wCap.c_str(),
                     mbType, 0 /* system lang */);
 
 	return flightgear::MSG_BOX_OK;
 }
-    
+
 #endif
-    
+
 } // anonymous namespace
 
 namespace flightgear
 {
-    
+
 MessageBoxResult modalMessageBox(const std::string& caption,
     const std::string& msg,
     const std::string& moreText)
@@ -116,9 +116,9 @@ MessageBoxResult modalMessageBox(const std::string& caption,
         args->setStringValue("message", msg);
         args->setStringValue("more", moreText);
         globals->get_commands()->execute("canvas-message-box", args);
-   
+
         // how to make it modal?
-        
+
         return MSG_BOX_OK;
     }
 
@@ -129,9 +129,18 @@ MessageBoxResult modalMessageBox(const std::string& caption,
 #elif defined(HAVE_QT)
     return QtMessageBox(caption, msg, moreText, false);
 #else
-    SG_LOG(SG_GENERAL, SG_ALERT, caption << ":" << msg);
+    std::string s = caption + ": "+ msg;
     if (!moreText.empty()) {
-        SG_LOG(SG_GENERAL, SG_ALERT, "(" << moreText << ")");
+        s += "\n( " +  moreText + ")";
+    }
+
+    NewGUI* gui = globals->get_subsystem<NewGUI>();
+    if (!gui || (fgGetBool("/sim/rendering/initialized", false) == false)) {
+        SG_LOG(SG_GENERAL, SG_ALERT, s);
+    } else {
+        SGPropertyNode_ptr dlg = gui->getDialogProperties("popup");
+        dlg->setStringValue("text/label", s  );
+        gui->showDialog("popup");
     }
     return MSG_BOX_OK;
 #endif
@@ -148,11 +157,18 @@ MessageBoxResult fatalMessageBox(const std::string& caption,
 #elif defined(HAVE_QT)
     return QtMessageBox(caption, msg, moreText, true);
 #else
-    std::cerr << "FATAL:" << msg << "\n";
+    std::string s = "FATAL: "+ msg;
     if (!moreText.empty()) {
-        std::cerr << "(" << moreText << ")";
+        s += "\n( " +  moreText + ")";
+    }
+    if (fgGetBool("/sim/rendering/initialized", false) == false) {
+        std::cerr << s << std::endl;
+    } else {
+        NewGUI* _gui = (NewGUI *)globals->get_subsystem("gui");
+        SGPropertyNode_ptr dlg = _gui->getDialogProperties("popup");
+        dlg->setStringValue("text/label", s  );
+        _gui->showDialog("popup");
     }
-    std::cerr << std::endl;
     return MSG_BOX_OK;
 #endif
 }
