@@ -33,6 +33,8 @@
 #include <string>
 
 #include <simgear/structure/exception.hxx>
+#include <simgear/structure/commands.hxx>
+
 #include <simgear/misc/sg_path.hxx>
 #include <simgear/props/props.hxx>
 #include <simgear/props/props_io.hxx>
@@ -77,7 +79,11 @@ public:
         puSetDefaultStyle         ( PUSTYLE_SMALL_SHADED ); //PUSTYLE_DEFAULT
         puSetDefaultColourScheme  (0.8, 0.8, 0.9, 1);
 
-        FGFontCache *fc = globals->get_fontcache();
+        // OSG Texture2D sets this, which breaks PLIB fntLoadTXF
+        // force it back to zero so width passed to glTexImage2D is used
+        glPixelStorei(GL_UNPACK_ROW_LENGTH, 0);
+
+        FGFontCache *fc = FGFontCache::instance();
         fc->initializeFonts();
         puFont *GuiFont
             = fc->get(globals->get_locale()->getDefaultFont("typewriter.txf"),
@@ -183,3 +189,17 @@ bool guiInit()
         return true;
     }
 }
+
+void syncPausePopupState()
+{
+    bool paused = fgGetBool("/sim/freeze/master",true) | fgGetBool("/sim/freeze/clock",true);
+    SGPropertyNode_ptr args(new SGPropertyNode);
+    args->setStringValue("id", "sim-pause");
+    if (paused && fgGetBool("/sim/view-name-popup")) {
+      args->setStringValue("label", "Simulation is paused");
+      globals->get_commands()->execute("show-message", args);
+    } else {
+      globals->get_commands()->execute("clear-message", args);
+    }
+
+}
