@@ -136,7 +136,7 @@ int main( int argc, char *argv[] ) {
 
     SGPropertyNode *templatetree = new SGPropertyNode();
     try {
-        readProperties(templatefile.str().c_str(), templatetree);
+        readProperties(templatefile, templatetree);
     } catch (sg_io_exception & e) {
         cout << e.getFormattedMessage ();
     }
@@ -258,7 +258,7 @@ static string fgScanForOption( const string& option, int argc, char **argv ) {
 
 // Scan the user config files for the specified option and return
 // the value.
-static string fgScanForOption( const string& option, const string& path ) {
+static string fgScanForOption( const string& option, const SGPath& path ) {
     sg_gzifstream in( path );
     if ( !in.is_open() ) {
         return "";
@@ -301,7 +301,7 @@ static string fgScanForOption( const string& option ) {
             config.append( ".fgfsrc" );
             config.concat( "." );
             config.concat( hostname );
-            arg = fgScanForOption( option, config.str() );
+            arg = fgScanForOption( option, config );
         }
     }
 #endif
@@ -311,7 +311,7 @@ static string fgScanForOption( const string& option ) {
         if ( homedir != NULL ) {
             SGPath config( homedir );
             config.append( ".fgfsrc" );
-            arg = fgScanForOption( option, config.str() );
+            arg = fgScanForOption( option, config );
         }
     }
 
@@ -346,10 +346,10 @@ string getFGRoot ( int argc, char **argv ) {
         root = "../data";
 #elif defined( _WIN32 )
         root = "..\\data";
-#elif defined(__APPLE__) 
+#elif defined(__APPLE__)
         /*
-        The following code looks for the base package inside the application 
-        bundle, in the standard Contents/Resources location. 
+        The following code looks for the base package inside the application
+        bundle, in the standard Contents/Resources location.
         */
 
         CFURLRef resourcesUrl = CFBundleCopyResourcesDirectoryURL(CFBundleGetMainBundle());
