@@ -307,12 +307,12 @@ void NavRadioComponent::update( double dt, const SGGeod & aircraftPosition )
 
 /* ---------------------------------------------------------------- */
 
-static std::string VORTablePath( const char * name )
+static SGPath VORTablePath( const char * name )
 {
     SGPath path( globals->get_fg_root() );
     path.append( "Navaids" );
     path.append(name);
-    return path.str();
+    return path;
 }
 
 class VOR : public NavRadioComponentWithIdent {
@@ -783,7 +783,7 @@ void GS::update( double dt, const SGGeod & aircraftPosition )
   double offset = _targetGlideslope_deg - gsDirect;
   if( offset < 0.0 )
     offset = _targetGlideslope_deg/2 * sawtooth(2.0*offset/_targetGlideslope_deg);
-  assert( false == isnan(offset) );
+    assert( false == SGMisc<double>::isNaN(offset) );
 // GS is documented to be 1.4 degrees thick, 
 // i.e. plus or minus 0.7 degrees from the midline:
   _glideslopeOffset_norm = SGMiscd::clip(offset/0.7, -1.0, 1.0);
@@ -842,6 +842,7 @@ private:
   double _stationTTL;
   double _frequency;
   PropertyObject<bool> _cdiDisconnected;
+  PropertyObject<std::string> _navType;
 };
 
 NavRadioImpl::NavRadioImpl( SGPropertyNode_ptr node ) :
@@ -854,7 +855,8 @@ NavRadioImpl::NavRadioImpl( SGPropertyNode_ptr node ) :
   _navIndicator(_rootNode),
   _stationTTL(0.0),
   _frequency(-1.0),
-  _cdiDisconnected(_rootNode->getNode("cdi-disconnected",true))
+  _cdiDisconnected(_rootNode->getNode("cdi-disconnected",true)),
+  _navType(_rootNode->getNode("nav-type",true))
 {
 }
 
@@ -912,6 +914,14 @@ void NavRadioImpl::update( double dt )
   if( _stationTTL <= 0.0 )
       _stationTTL = 30.0;
 
+  if( _components[VOR_COMPONENT]->valid() ) {
+    _navType = "vor";
+  } else if( _components[LOC_COMPONENT]->valid() ) {
+    _navType = "loc";
+  } else {
+    _navType = "";
+  }
+
   _legacy.update( dt );
 }
 
