@@ -78,6 +78,8 @@
 #include <Aircraft/controls.hxx>
 #include <Aircraft/replay.hxx>
 #include <Aircraft/FlightHistory.hxx>
+#include <Aircraft/initialstate.hxx>
+
 #include <Airports/runways.hxx>
 #include <Airports/airport.hxx>
 #include <Airports/dynamics.hxx>
@@ -170,7 +172,7 @@ string fgBasePackageVersion(const SGPath& base_path) {
         return string();
     }
     
-    sg_gzifstream in( p.str() );
+    sg_gzifstream in( p );
     if (!in.is_open()) {
         return string();
     }
@@ -208,7 +210,7 @@ public:
         SG_LOG(SG_GENERAL, SG_INFO, "found aircraft in dir: " << aircraftDir );
         
         try {
-          readProperties(setFile.str(), globals->get_props());
+          readProperties(setFile, globals->get_props());
         } catch ( const sg_exception &e ) {
           SG_LOG(SG_INPUT, SG_ALERT, "Error reading aircraft: " << e.getFormattedMessage());
             flightgear::fatalMessageBox("Error reading aircraft",
@@ -216,7 +218,8 @@ public:
                                         e.getFormattedMessage());
           return false;
         }
-        
+          // apply state after the -set.xml, but before any options are are set
+          flightgear::applyInitialState();
         return true;
       } else {
         SG_LOG(SG_GENERAL, SG_ALERT, "aircraft '" << _searchAircraft << 
@@ -231,7 +234,7 @@ public:
     if (!checkCache()) {
       // prepare cache for re-scan
       SGPropertyNode *n = _cache->getNode("fg-root", true);
-      n->setStringValue(globals->get_fg_root().c_str());
+      n->setStringValue(globals->get_fg_root().utf8Str());
       n->setAttribute(SGPropertyNode::USERARCHIVE, true);
       n = _cache->getNode("fg-aircraft", true);
       n->setStringValue(getAircraftPaths().c_str());
@@ -241,7 +244,7 @@ public:
         visitAircraftPaths();
     }
     
-    if (_foundPath.str().empty()) {
+    if (_foundPath.isNull()) {
       SG_LOG(SG_GENERAL, SG_ALERT, "Cannot find specified aircraft: " << aircraft );
         flightgear::fatalMessageBox("Aircraft not found",
                                     "The requested aircraft '" + aircraft + "' could not be found in any of the search paths");
@@ -249,15 +252,15 @@ public:
       return false;
     }
     
-    SG_LOG(SG_GENERAL, SG_INFO, "Loading aircraft -set file from:" << _foundPath.str());
+    SG_LOG(SG_GENERAL, SG_INFO, "Loading aircraft -set file from:" << _foundPath);
     fgSetString( "/sim/aircraft-dir", _foundPath.dir().c_str());
     if (!_foundPath.exists()) {
-      SG_LOG(SG_GENERAL, SG_ALERT, "Unable to find -set file:" << _foundPath.str());
+      SG_LOG(SG_GENERAL, SG_ALERT, "Unable to find -set file:" << _foundPath);
       return false;
     }
     
     try {
-      readProperties(_foundPath.str(), globals->get_props());
+      readProperties(_foundPath, globals->get_props());
     } catch ( const sg_exception &e ) {
       SG_LOG(SG_INPUT, SG_ALERT, "Error reading aircraft: " << e.getFormattedMessage());
         flightgear::fatalMessageBox("Error reading aircraft",
@@ -265,32 +268,27 @@ public:
                                     e.getFormattedMessage());
       return false;
     }
-    
+
+      // apply state after the -set.xml, but before any options are are set
+      flightgear::applyInitialState();
+
+
     return true;
   }
   
 private:
-  SGPath getAircraftPaths() {
-    string_list pathList = globals->get_aircraft_paths();
-    SGPath aircraftPaths;
-    string_list::const_iterator it = pathList.begin();
-    if (it != pathList.end()) {
-        aircraftPaths.set(*it);
-        it++;
+    std::string getAircraftPaths()
+    {
+        return SGPath::join(globals->get_aircraft_paths(), ";");
     }
-    for (; it != pathList.end(); ++it) {
-        aircraftPaths.add(*it);
-    }
-    return aircraftPaths;
-  }
   
   bool checkCache()
   {
-    if (globals->get_fg_root() != _cache->getStringValue("fg-root", "")) {
+    if (globals->get_fg_root().utf8Str() != _cache->getStringValue("fg-root", "")) {
       return false; // cache mismatch
     }
 
-    if (getAircraftPaths().str() != _cache->getStringValue("fg-aircraft", "")) {
+    if (getAircraftPaths() != _cache->getStringValue("fg-aircraft", "")) {
       return false; // cache mismatch
     }
     
@@ -370,7 +368,7 @@ static SGPath platformDefaultDataPath()
 bool fgInitHome()
 {
   SGPath dataPath = SGPath::fromEnv("FG_HOME", platformDefaultDataPath());
-  globals->set_fg_home(dataPath.c_str());
+  globals->set_fg_home(dataPath);
     
     simgear::Dir fgHome(dataPath);
     if (!fgHome.exists()) {
@@ -380,7 +378,7 @@ bool fgInitHome()
     if (!fgHome.exists()) {
         flightgear::fatalMessageBox("Problem setting up user data",
                                     "Unable to create the user-data storage folder at: '"
-                                    + dataPath.str() + "'");
+                                    + dataPath.utf8Str() + "'");
         return false;
     }
     
@@ -402,10 +400,11 @@ bool fgInitHome()
     
     char buf[16];
     bool result = false;
+    std::string ps = pidPath.local8BitStr();
 #if defined(SG_WINDOWS)
     size_t len = snprintf(buf, 16, "%d", _getpid());
 
-    HANDLE f = CreateFileA(pidPath.c_str(), GENERIC_READ | GENERIC_WRITE, 
+    HANDLE f = CreateFileA(ps.c_str(), GENERIC_READ | GENERIC_WRITE,
 						   FILE_SHARE_READ, /* sharing */
                            NULL, /* security attributes */
                            CREATE_NEW, /* error if already exists */
@@ -421,10 +420,10 @@ bool fgInitHome()
     // POSIX, do open+unlink trick to the file is deleted on exit, even if we
     // crash or exit(-1)
     ssize_t len = snprintf(buf, 16, "%d", getpid());
-    int fd = ::open(pidPath.c_str(), O_WRONLY | O_CREAT | O_TRUNC | O_EXCL, 0644);
+    int fd = ::open(ps.c_str(), O_WRONLY | O_CREAT | O_TRUNC | O_EXCL, 0644);
     if (fd >= 0) {
         result = ::write(fd, buf, len) == len;
-        if( ::unlink(pidPath.c_str()) != 0 ) // delete file when app quits
+        if( ::unlink(ps.c_str()) != 0 ) // delete file when app quits
           result = false;
     }
 #endif
@@ -434,7 +433,7 @@ bool fgInitHome()
     if (!result) {
         flightgear::fatalMessageBox("File permissions problem",
                                     "Can't write to user-data storage folder, check file permissions and FG_HOME.",
-                                    "User-data at:" + dataPath.str());
+                                    "User-data at:" + dataPath.utf8Str());
     }
     return result;
 }
@@ -455,7 +454,7 @@ int fgInitConfig ( int argc, char **argv, bool reinit )
     SGPropertyNode *home = fgGetNode("/sim", true);
     home->removeChild("fg-home", 0);
     home = home->getChild("fg-home", 0, true);
-    home->setStringValue(dataPath.c_str());
+    home->setStringValue(dataPath.utf8Str());
     home->setAttribute(SGPropertyNode::WRITE, false);
   
     fgSetDefaults();
@@ -463,28 +462,21 @@ int fgInitConfig ( int argc, char **argv, bool reinit )
     if (!reinit) {
         options->init(argc, argv, dataPath);
     }
-    
-    bool loadDefaults = options->shouldLoadDefaultConfig();
-    if (loadDefaults) {
-      // Read global preferences from $FG_ROOT/preferences.xml
-      SG_LOG(SG_INPUT, SG_INFO, "Reading global preferences");
-      fgLoadProps("preferences.xml", globals->get_props());
-      SG_LOG(SG_INPUT, SG_INFO, "Finished Reading global preferences");
-        
-      // do not load user settings when reset to default is requested, or if
-      // told to explicitly ignore
-      if (options->isOptionSet("restore-defaults") || options->isOptionSet("ignore-autosave"))
-      {
-          SG_LOG(SG_GENERAL, SG_ALERT, "Ignoring user settings. Restoring defaults.");
-      }
-      else
-      {
-          globals->loadUserSettings(dataPath);
-      }
+
+    // Read global preferences from $FG_ROOT/preferences.xml
+    SG_LOG(SG_GENERAL, SG_INFO, "Reading global preferences");
+    fgLoadProps("preferences.xml", globals->get_props());
+    SG_LOG(SG_GENERAL, SG_INFO, "Finished Reading global preferences");
+
+    // do not load user settings when reset to default is requested, or if
+    // told to explicitly ignore
+    if (options->isOptionSet("restore-defaults") || options->isOptionSet("ignore-autosave"))
+    {
+        SG_LOG(SG_GENERAL, SG_ALERT, "Ignoring user settings. Restoring defaults.");
     } else {
-      SG_LOG(SG_GENERAL, SG_INFO, "not reading default configuration files");
-    }// of no-default-config selected
-    
+        globals->loadUserSettings(dataPath);
+    }
+
     return flightgear::FG_OPTIONS_OK;
 }
 
@@ -496,13 +488,12 @@ static void initAircraftDirsNasalSecurity()
     sim->removeChildren("fg-aircraft");
 
     int index = 0;
-    string_list const aircraft_paths = globals->get_aircraft_paths();
-    for( string_list::const_iterator it = aircraft_paths.begin();
-                                     it != aircraft_paths.end();
-                                   ++it, ++index )
+    const PathList& aircraft_paths = globals->get_aircraft_paths();
+    for (PathList::const_iterator it = aircraft_paths.begin();
+         it != aircraft_paths.end(); ++it, ++index )
     {
         SGPropertyNode* n = sim->getChild("fg-aircraft", index, true);
-        n->setStringValue(*it);
+        n->setStringValue(it->utf8Str());
         n->setAttribute(SGPropertyNode::WRITE, false);
     }
 }
@@ -543,7 +534,7 @@ int fgInitAircraft(bool reinit)
 
             // set aircraft-dir to short circuit the search process
             InstallRef acftInstall = acftPackage->install();
-            fgSetString("/sim/aircraft-dir", acftInstall->path().c_str());
+            fgSetString("/sim/aircraft-dir", acftInstall->path().utf8Str());
 
             // overwrite the fully qualified ID with the aircraft one, so the
             // code in FindAndCacheAircraft works as normal
@@ -598,7 +589,8 @@ fgInitNav ()
 
     static const char* splashIdentsByRebuildPhase[] = {
         "loading-nav-dat",
-        "navdata-airports",
+        "navdata-reading-apt-dat-files",
+        "navdata-loading-airports",
         "navdata-navaids",
         "navdata-fixes",
         "navdata-pois"
@@ -631,20 +623,18 @@ fgInitNav ()
 
 // General house keeping initializations
 bool fgInitGeneral() {
-    string root;
 
     SG_LOG( SG_GENERAL, SG_INFO, "General Initialization" );
     SG_LOG( SG_GENERAL, SG_INFO, "======= ==============" );
 
-    root = globals->get_fg_root();
-    if ( ! root.length() ) {
+    if ( globals->get_fg_root().isNull() ) {
         // No root path set? Then bail ...
         SG_LOG( SG_GENERAL, SG_ALERT,
                 "Cannot continue without a path to the base package "
                 << "being defined." );
         return false;
     }
-    SG_LOG( SG_GENERAL, SG_INFO, "FG_ROOT = " << '"' << root << '"' << endl );
+    SG_LOG( SG_GENERAL, SG_INFO, "FG_ROOT = " << '"' << globals->get_fg_root() << '"' << endl );
 
     // Note: browser command is hard-coded for Mac/Windows, so this only affects other platforms
     globals->set_browser(fgGetString("/sim/startup/browser-app", WEB_BROWSER));
@@ -654,7 +644,7 @@ bool fgInitGeneral() {
     SGPropertyNode *curr = fgGetNode("/sim", true);
     curr->removeChild("fg-current", 0);
     curr = curr->getChild("fg-current", 0, true);
-    curr->setStringValue(cwd.path().str());
+    curr->setStringValue(cwd.path().utf8Str());
     curr->setAttribute(SGPropertyNode::WRITE, false);
 
     fgSetBool("/sim/startup/stdout-to-terminal", isatty(1) != 0 );
@@ -676,8 +666,8 @@ void fgOutputSettings()
     SG_LOG( SG_GENERAL, SG_INFO, "download-dir = " << '"' << fgGetString("/sim/paths/download-dir") << '"' );
     SG_LOG( SG_GENERAL, SG_INFO, "terrasync-dir = " << '"' << fgGetString("/sim/terrasync/scenery-dir") << '"' );
 
-    SG_LOG( SG_GENERAL, SG_INFO, "aircraft-search-paths = \n\t" << simgear::strutils::join(globals->get_aircraft_paths(), "\n\t") );
-    SG_LOG( SG_GENERAL, SG_INFO, "scenery-search-paths = \n\t" << simgear::strutils::join(globals->get_fg_scenery(), "\n\t") );
+    SG_LOG( SG_GENERAL, SG_INFO, "aircraft-search-paths = \n\t" << SGPath::join(globals->get_aircraft_paths(), "\n\t") );
+    SG_LOG( SG_GENERAL, SG_INFO, "scenery-search-paths = \n\t" << SGPath::join(globals->get_fg_scenery(), "\n\t") );
 }
 
 // This is the top level init routine which calls all the other
@@ -736,7 +726,7 @@ void fgCreateSubsystems(bool duringReset) {
 
     SGPath mpath( globals->get_fg_root() );
     mpath.append( fgGetString("/sim/rendering/materials-file") );
-    if ( ! globals->get_matlib()->load(globals->get_fg_root(), mpath.str(),
+    if ( ! globals->get_matlib()->load(globals->get_fg_root().local8BitStr(), mpath.local8BitStr(),
             globals->get_props()) ) {
        throw sg_io_exception("Error loading materials file", mpath);
     }
@@ -908,8 +898,7 @@ void fgPostInitSubsystems()
     // Initialize the Nasal interpreter.
     // Do this last, so that the loaded scripts see initialized state
     ////////////////////////////////////////////////////////////////////////
-    FGNasalSys* nasal = new FGNasalSys();
-    globals->add_subsystem("nasal", nasal, SGSubsystemMgr::INIT);
+    FGNasalSys* nasal = globals->add_new_subsystem<FGNasalSys>(SGSubsystemMgr::INIT);
     nasal->init();
     SG_LOG(SG_GENERAL, SG_INFO, "Nasal init took:" << st.elapsedMSec());
 
@@ -1142,7 +1131,7 @@ void fgInitPackageRoot()
 
     packageAircraftDir.append("Aircraft");
 
-    SG_LOG(SG_GENERAL, SG_INFO, "init package root at:" << packageAircraftDir.str());
+    SG_LOG(SG_GENERAL, SG_INFO, "init package root at:" << packageAircraftDir);
 
 
     SGSharedPtr<Root> pkgRoot(new Root(packageAircraftDir, FLIGHTGEAR_VERSION));
