@@ -31,7 +31,7 @@
 #include <simgear/timing/sg_time.hxx>
 #include <simgear/misc/sg_path.hxx>
 #include <simgear/scene/model/particles.hxx>
-#include <simgear/sound/soundmgr_openal.hxx>
+#include <simgear/sound/soundmgr.hxx>
 
 #include <GUI/gui.h>
 
@@ -178,6 +178,7 @@ getLoggingPriority ()
   case SG_WARN:
     return "warn";
   case SG_ALERT:
+  case SG_POPUP:
     return "alert";
   default:
     SG_LOG(SG_GENERAL, SG_WARN, "Internal: Unknown logging priority number: "
@@ -575,18 +576,18 @@ FGProperties::bind ()
   _tiedProperties.Tie("/sim/logging/classes", getLoggingClasses, setLoggingClasses);
   _tiedProperties.Tie("/sim/freeze/master", getFreeze, setFreeze);
 
-  _tiedProperties.Tie("/sim/time/elapsed-sec", getElapsedTime_sec);
+  _tiedProperties.Tie<double>("/sim/time/elapsed-sec", getElapsedTime_sec);
   _tiedProperties.Tie("/sim/time/gmt", getDateString, setDateString);
   fgSetArchivable("/sim/time/gmt");
-  _tiedProperties.Tie("/sim/time/gmt-string", getGMTString);
+  _tiedProperties.Tie<const char*>("/sim/time/gmt-string", getGMTString);
 
   // Position
-  _tiedProperties.Tie("/position/latitude-string", getLatitudeString);
-  _tiedProperties.Tie("/position/longitude-string", getLongitudeString);
+  _tiedProperties.Tie<const char*>("/position/latitude-string", getLatitudeString);
+  _tiedProperties.Tie<const char*>("/position/longitude-string", getLongitudeString);
 
   // Orientation
-  _tiedProperties.Tie("/orientation/heading-magnetic-deg", getHeadingMag);
-  _tiedProperties.Tie("/orientation/track-magnetic-deg", getTrackMag);
+  _tiedProperties.Tie<double>("/orientation/heading-magnetic-deg", getHeadingMag);
+  _tiedProperties.Tie<double>("/orientation/track-magnetic-deg", getTrackMag);
 }
 
 void
@@ -684,15 +685,15 @@ fgLoadFlight (std::istream &input)
 
 
 bool
-fgLoadProps (const char * path, SGPropertyNode * props, bool in_fg_root, int default_mode)
+fgLoadProps (const std::string& path, SGPropertyNode * props, bool in_fg_root, int default_mode)
 {
-    string fullpath;
+    SGPath fullpath;
     if (in_fg_root) {
         SGPath loadpath(globals->get_fg_root());
         loadpath.append(path);
-        fullpath = loadpath.str();
+        fullpath = loadpath;
     } else {
-        fullpath = path;
+        fullpath = SGPath::fromUtf8(path);
     }
 
     try {
