@@ -38,7 +38,7 @@
 #include <simgear/scene/material/matlib.hxx>
 #include <simgear/structure/subsystem_mgr.hxx>
 #include <simgear/structure/event_mgr.hxx>
-#include <simgear/sound/soundmgr_openal.hxx>
+#include <simgear/sound/soundmgr.hxx>
 #include <simgear/misc/ResourceManager.hxx>
 #include <simgear/props/propertyObject.hxx>
 #include <simgear/props/props_io.hxx>
@@ -108,10 +108,11 @@ public:
 
   // try each aircraft dir in turn
     std::string res(aResource, 9); // resource path with 'Aircraft/' removed
-    const string_list& dirs(globals->get_aircraft_paths());
-    string_list::const_iterator it = dirs.begin();
+    const PathList& dirs(globals->get_aircraft_paths());
+    PathList::const_iterator it = dirs.begin();
     for (; it != dirs.end(); ++it) {
-      SGPath p(*it, res);
+        SGPath p(*it);
+        p.append(res);
       if (p.exists()) {
         return p;
       }
@@ -131,8 +132,7 @@ public:
 
   virtual SGPath resolve(const std::string& aResource, SGPath&) const
   {
-    const char* aircraftDir = fgGetString("/sim/aircraft-dir");
-    SGPath p(aircraftDir);
+      SGPath p = SGPath::fromUtf8(fgGetString("/sim/aircraft-dir"));
     p.append(aResource);
     return p.exists() ? p : SGPath();
   }
@@ -248,7 +248,7 @@ FGGlobals::~FGGlobals()
 }
 
 // set the fg_root path
-void FGGlobals::set_fg_root (const std::string &root) {
+void FGGlobals::set_fg_root (const SGPath &root) {
     SGPath tmp(root);
     fg_root = tmp.realpath();
 
@@ -256,9 +256,9 @@ void FGGlobals::set_fg_root (const std::string &root) {
     tmp.append( "data" );
     tmp.append( "version" );
     if ( tmp.exists() ) {
-        fgGetNode("BAD_FG_ROOT", true)->setStringValue(fg_root);
-        fg_root += "/data";
-        fgGetNode("GOOD_FG_ROOT", true)->setStringValue(fg_root);
+        fgGetNode("BAD_FG_ROOT", true)->setStringValue(fg_root.utf8Str());
+        fg_root.append("data");
+        fgGetNode("GOOD_FG_ROOT", true)->setStringValue(fg_root.utf8Str());
         SG_LOG(SG_GENERAL, SG_ALERT, "***\n***\n*** Warning: changing bad FG_ROOT/--fg-root to '"
                 << fg_root << "'\n***\n***");
     }
@@ -268,7 +268,7 @@ void FGGlobals::set_fg_root (const std::string &root) {
     SGPropertyNode *n = fgGetNode("/sim", true);
     n->removeChild("fg-root", 0);
     n = n->getChild("fg-root", 0, true);
-    n->setStringValue(fg_root.c_str());
+    n->setStringValue(fg_root.utf8Str());
     n->setAttribute(SGPropertyNode::WRITE, false);
 
     simgear::ResourceManager::instance()->addBasePath(fg_root,
@@ -276,15 +276,15 @@ void FGGlobals::set_fg_root (const std::string &root) {
 }
 
 // set the fg_home path
-void FGGlobals::set_fg_home (const std::string &home) {
-    SGPath tmp(home);
-    fg_home = tmp.realpath();
+void FGGlobals::set_fg_home (const SGPath &home)
+{
+    fg_home = home.realpath();
 }
 
 PathList FGGlobals::get_data_paths() const
 {
     PathList r(additional_data_paths);
-    r.push_back(SGPath(fg_root));
+    r.push_back(fg_root);
     return r;
 }
 
@@ -329,96 +329,154 @@ SGPath FGGlobals::find_data_dir(const std::string& pathSuffix) const
     return SGPath();
 }
 
-void FGGlobals::append_fg_scenery (const std::string &paths, bool secure)
+void FGGlobals::append_fg_scenery (const PathList &paths)
+{
+    BOOST_FOREACH(const SGPath& path, paths) {
+        append_fg_scenery(path);
+    }
+}
+
+void FGGlobals::append_fg_scenery (const SGPath &path)
 {
     SGPropertyNode* sim = fgGetNode("/sim", true);
 
-  // find first unused fg-scenery property in /sim
+    // find first unused fg-scenery property in /sim
     int propIndex = 0;
     while (sim->getChild("fg-scenery", propIndex) != NULL) {
-      ++propIndex;
+        ++propIndex;
     }
 
-    BOOST_FOREACH(const SGPath& path, sgPathSplit( paths )) {
-        SGPath abspath(path.realpath());
-        if (!abspath.exists()) {
-          SG_LOG(SG_GENERAL, SG_WARN, "scenery path not found:" << abspath.str());
-          continue;
-        }
+    SGPath abspath(path.realpath());
+    if (!abspath.exists()) {
+        SG_LOG(SG_GENERAL, SG_WARN, "scenery path not found:" << abspath);
+        return;
+    }
 
-      // check for duplicates
-      string_list::const_iterator ex = std::find(fg_scenery.begin(), fg_scenery.end(), abspath.str());
-      if (ex != fg_scenery.end()) {
-        SG_LOG(SG_GENERAL, SG_INFO, "skipping duplicate add of scenery path:" << abspath.str());
-        continue;
-      }
+    // check for duplicates
+    PathList::const_iterator ex = std::find(fg_scenery.begin(), fg_scenery.end(), abspath);
+    if (ex != fg_scenery.end()) {
+        SG_LOG(SG_GENERAL, SG_INFO, "skipping duplicate add of scenery path:" << abspath);
+        return;
+    }
 
-      // tell the ResouceManager about the scenery path
-      // needed to load Models from this scenery path
-      simgear::ResourceManager::instance()->addBasePath(abspath.str(),
-        simgear::ResourceManager::PRIORITY_DEFAULT);
+    // tell the ResouceManager about the scenery path
+    // needed to load Models from this scenery path
+    simgear::ResourceManager::instance()->addBasePath(abspath.local8BitStr(),
+                                                      simgear::ResourceManager::PRIORITY_DEFAULT);
 
-        simgear::Dir dir(abspath);
-        SGPath terrainDir(dir.file("Terrain"));
-        SGPath objectsDir(dir.file("Objects"));
+    simgear::Dir dir(abspath);
+    SGPath terrainDir(dir.file("Terrain"));
+    SGPath objectsDir(dir.file("Objects"));
 
-      // this code used to add *either* the base dir, OR add the
-      // Terrain and Objects subdirs, but the conditional logic was commented
-      // out, such that all three dirs are added. Unfortunately there's
-      // no information as to why the change was made.
-        fg_scenery.push_back(abspath.str());
-        if (secure) {
-          secure_fg_scenery.push_back(abspath.str());
-        }
+    // this code used to add *either* the base dir, OR add the
+    // Terrain and Objects subdirs, but the conditional logic was commented
+    // out, such that all three dirs are added. Unfortunately there's
+    // no information as to why the change was made.
+    fg_scenery.push_back(abspath);
+    unmangled_fg_scenery.push_back(abspath);
+    extra_read_allowed_paths.push_back(abspath);
 
-        if (terrainDir.exists()) {
-          fg_scenery.push_back(terrainDir.str());
-        }
+    if (terrainDir.exists()) {
+        fg_scenery.push_back(terrainDir);
+    }
 
-        if (objectsDir.exists()) {
-          fg_scenery.push_back(objectsDir.str());
-        }
+    if (objectsDir.exists()) {
+        fg_scenery.push_back(objectsDir);
+    }
 
-        // insert a marker for FGTileEntry::load(), so that
-        // FG_SCENERY=A:B becomes list ["A/Terrain", "A/Objects", "",
-        // "B/Terrain", "B/Objects", ""]
-        fg_scenery.push_back("");
+    // insert a marker for FGTileEntry::load(), so that
+    // FG_SCENERY=A:B becomes list ["A/Terrain", "A/Objects", "",
+    // "B/Terrain", "B/Objects", ""]
+    fg_scenery.push_back(SGPath());
 
-      // make scenery dirs available to Nasal
-        SGPropertyNode* n = sim->getChild("fg-scenery", propIndex++, true);
-        n->setStringValue(abspath.str());
-        n->setAttribute(SGPropertyNode::WRITE, false);
+    // make scenery dirs available to Nasal
+    SGPropertyNode* n = sim->getChild("fg-scenery", propIndex++, true);
+    n->setStringValue(abspath.utf8Str());
+    n->setAttribute(SGPropertyNode::WRITE, false);
+    
+    // temporary fix so these values survive reset
+    n->setAttribute(SGPropertyNode::PRESERVE, true);
+}
 
-        // temporary fix so these values survive reset
-        n->setAttribute(SGPropertyNode::PRESERVE, true);
-    } // of path list iteration
+void FGGlobals::append_read_allowed_paths(const SGPath &path)
+{
+    SGPath abspath(path.realpath());
+    if (!abspath.exists()) {
+        SG_LOG(SG_GENERAL, SG_WARN, "read-allowed path not found:" << abspath);
+        return;
+    }
+    extra_read_allowed_paths.push_back(abspath);
 }
 
 void FGGlobals::clear_fg_scenery()
 {
   fg_scenery.clear();
-  secure_fg_scenery.clear();
+  unmangled_fg_scenery.clear();
   fgGetNode("/sim", true)->removeChildren("fg-scenery");
 
 }
 
+// The 'path' argument to this method must come from trustworthy code, because
+// the method grants read permissions to Nasal code for many files beneath
+// 'path'. In particular, don't call this method with a 'path' value taken
+// from the property tree or any other Nasal-writable place.
+void FGGlobals::set_download_dir(const SGPath& path)
+{
+  SGPath abspath(path.realpath());
+  download_dir = abspath;
+
+  append_read_allowed_paths(abspath / "Aircraft");
+  append_read_allowed_paths(abspath / "AI");
+  append_read_allowed_paths(abspath / "Liveries");
+  // If in use, abspath / TerraSync will be added to 'extra_read_allowed_paths'
+  // by FGGlobals::append_fg_scenery(), as any scenery path.
+
+  SGPropertyNode *n = fgGetNode("/sim/paths/download-dir", true);
+  n->setAttribute(SGPropertyNode::WRITE, true);
+  n->setStringValue(abspath.utf8Str());
+  n->setAttribute(SGPropertyNode::WRITE, false);
+}
+
+// The 'path' argument to this method must come from trustworthy code, because
+// the method grants read permissions to Nasal code for all files beneath
+// 'path'. In particular, don't call this method with a 'path' value taken
+// from the property tree or any other Nasal-writable place.
+void FGGlobals::set_terrasync_dir(const SGPath &path)
+{
+  if (terrasync_dir.realpath() != SGPath(fgGetString("/sim/terrasync/scenery-dir")).realpath()) {
+    // if they don't match, /sim/terrasync/scenery-dir has been set by something else
+    SG_LOG(SG_GENERAL, SG_ALERT, "/sim/terrasync/scenery-dir is no longer stored across runs: if you wish to keep using a non-standard Terrasync directory, use --terrasync-dir or the launcher's settings");
+  }
+  SGPath abspath(path.realpath());
+  terrasync_dir = abspath;
+  // deliberately not a tied property, for fgValidatePath security
+  // write-protect to avoid accidents
+  SGPropertyNode *n = fgGetNode("/sim/terrasync/scenery-dir", true);
+  n->setAttribute(SGPropertyNode::WRITE, true);
+  n->setStringValue(abspath.utf8Str());
+  n->setAttribute(SGPropertyNode::WRITE, false);
+  // don't add it to fg_scenery yet, as we want it ordered after explicit --fg-scenery
+}
+
+
+
 void FGGlobals::set_catalog_aircraft_path(const SGPath& path)
 {
     catalog_aircraft_dir = path;
 }
 
-string_list FGGlobals::get_aircraft_paths() const
+PathList FGGlobals::get_aircraft_paths() const
 {
-    string_list r;
+    PathList r;
     if (!catalog_aircraft_dir.isNull()) {
-        r.push_back(catalog_aircraft_dir.str());
+        r.push_back(catalog_aircraft_dir);
     }
 
     r.insert(r.end(), fg_aircraft_dirs.begin(), fg_aircraft_dirs.end());
     return r;
 }
 
-void FGGlobals::append_aircraft_path(const std::string& path)
+void FGGlobals::append_aircraft_path(const SGPath& path)
 {
   SGPath dirPath(path);
   if (!dirPath.exists()) {
@@ -438,13 +496,12 @@ void FGGlobals::append_aircraft_path(const std::string& path)
       dirPath = acSubdir;
   }
 
-  std::string abspath = dirPath.realpath();
-  fg_aircraft_dirs.push_back(abspath);
+  fg_aircraft_dirs.push_back(dirPath.realpath());
+  extra_read_allowed_paths.push_back(dirPath.realpath());
 }
 
-void FGGlobals::append_aircraft_paths(const std::string& path)
+void FGGlobals::append_aircraft_paths(const PathList& paths)
 {
-  string_list paths = sgPathSplit(path);
   for (unsigned int p = 0; p<paths.size(); ++p) {
     append_aircraft_path(paths[p]);
   }
@@ -608,7 +665,7 @@ FGGlobals::resetPropertyRoot()
     SGPropertyNode *n = props->getNode("/sim", true);
     n->removeChild("fg-root", 0);
     n = n->getChild("fg-root", 0, true);
-    n->setStringValue(fg_root.c_str());
+    n->setStringValue(fg_root.utf8Str());
     n->setAttribute(SGPropertyNode::WRITE, false);
 }
 
@@ -624,19 +681,33 @@ static std::string autosaveName()
     return os.str();
 }
 
-// Load user settings from autosave.xml
-void
-FGGlobals::loadUserSettings(const SGPath& dataPath)
+SGPath FGGlobals::autosaveFilePath(SGPath userDataPath) const
 {
-    // remember that we have (tried) to load any existing autsave.xml
+    if (userDataPath.isNull()) {
+        userDataPath = get_fg_home();
+    }
+
+    return simgear::Dir(userDataPath).file(autosaveName());
+}
+
+// Load user settings from the autosave file (normally in $FG_HOME)
+void
+FGGlobals::loadUserSettings(SGPath userDataPath)
+{
+    if (userDataPath.isNull()) {
+        userDataPath = get_fg_home();
+    }
+
+    // Remember that we have (tried) to load any existing autosave file
     haveUserSettings = true;
 
-    SGPath autosaveFile = simgear::Dir(dataPath).file(autosaveName());
+    SGPath autosaveFile = autosaveFilePath(userDataPath);
     SGPropertyNode autosave;
     if (autosaveFile.exists()) {
-      SG_LOG(SG_INPUT, SG_INFO, "Reading user settings from " << autosaveFile.str());
+      SG_LOG(SG_INPUT, SG_INFO,
+             "Reading user settings from " << autosaveFile);
       try {
-          readProperties(autosaveFile.str(), &autosave, SGPropertyNode::USERARCHIVE);
+          readProperties(autosaveFile, &autosave, SGPropertyNode::USERARCHIVE);
       } catch (sg_exception& e) {
           SG_LOG(SG_INPUT, SG_WARN, "failed to read user settings:" << e.getMessage()
             << "(from " << e.getOrigin() << ")");
@@ -645,10 +716,19 @@ FGGlobals::loadUserSettings(const SGPath& dataPath)
     copyProperties(&autosave, globals->get_props());
 }
 
-// Save user settings in autosave.xml
+// Save user settings to the autosave file.
+//
+// When calling this method, make sure the value of 'userDataPath' is
+// trustworthy. In particular, make sure it can't be influenced by Nasal code,
+// not even indirectly via a Nasal-writable place such as the property tree.
+//
+// Note: the default value, which causes the autosave file to be written to
+//       $FG_HOME, is safe---if not, it would be a bug.
 void
-FGGlobals::saveUserSettings()
+FGGlobals::saveUserSettings(SGPath userDataPath)
 {
+    if (userDataPath.isNull()) userDataPath = get_fg_home();
+
     // only save settings when we have (tried) to load the previous
     // settings (otherwise user data was lost)
     if (!haveUserSettings)
@@ -658,12 +738,11 @@ FGGlobals::saveUserSettings()
       // don't save settings more than once on shutdown
       haveUserSettings = false;
 
-      SGPath autosaveFile(globals->get_fg_home());
-      autosaveFile.append(autosaveName());
+      SGPath autosaveFile = autosaveFilePath(userDataPath);
       autosaveFile.create_dir( 0700 );
-      SG_LOG(SG_IO, SG_INFO, "Saving user settings to " << autosaveFile.str());
+      SG_LOG(SG_IO, SG_INFO, "Saving user settings to " << autosaveFile);
       try {
-        writeProperties(autosaveFile.str(), globals->get_props(), false, SGPropertyNode::USERARCHIVE);
+        writeProperties(autosaveFile, globals->get_props(), false, SGPropertyNode::USERARCHIVE);
       } catch (const sg_exception &e) {
         guiErrorMessage("Error writing autosave:", e);
       }
