@@ -102,6 +102,12 @@ static TimeManager* timeMgr;
 // for the next move and update the display?
 static void fgMainLoop( void )
 {
+
+    if (sglog().has_popup()) {
+        std::string s = sglog().get_popup();
+        flightgear::modalMessageBox("Alert", s, "");
+    }
+
     frame_signal->fireValueChanged();
 
     // compute simulated time (allowing for pause, warp, etc) and
@@ -119,7 +125,7 @@ static void initTerrasync()
 {
     // add the terrasync root as a data path so data can be retrieved from it
     // (even if we are in read-only mode)
-    std::string terraSyncDir(fgGetString("/sim/terrasync/scenery-dir"));
+    SGPath terraSyncDir(globals->get_terrasync_dir());
     globals->append_data_path(terraSyncDir);
     
     if (fgGetBool("/sim/fghome-readonly", false)) {
@@ -140,8 +146,12 @@ static void initTerrasync()
         }
     }
     
-    fgSetString("/sim/terrasync/cache-path", tsyncCache.c_str());
-    
+    fgSetString("/sim/terrasync/cache-path", tsyncCache.utf8Str());
+
+    // make fg-root dir available so existing Scenery data can be copied, and
+    // hence not downloaded again.
+    fgSetString("/sim/terrasync/installation-dir", (globals->get_fg_root() / "Scenery").utf8Str());
+
     simgear::SGTerraSync* terra_sync = new simgear::SGTerraSync();
     terra_sync->setRoot(globals->get_props());
     globals->add_subsystem("terrasync", terra_sync);
@@ -171,20 +181,18 @@ static void fgSetVideoOptions()
         }
         path.append(renderer+".xml");
         if (path.exists()) {
-            SG_LOG(SG_INPUT, SG_INFO, "Reading video settings from " << path.str());
+            SG_LOG(SG_INPUT, SG_INFO, "Reading video settings from " << path);
             try {
                 SGPropertyNode *r_prop = fgGetNode("/sim/rendering");
-                readProperties(path.str(), r_prop);
+                readProperties(path, r_prop);
             } catch (sg_exception& e) {
                 SG_LOG(SG_INPUT, SG_WARN, "failed to read video settings:" << e.getMessage()
                 << "(from " << e.getOrigin() << ")");
             }
 
             flightgear::Options* options = flightgear::Options::sharedInstance();
-            if (!options->isOptionSet("ignore-autosave"))
-            {
-                SGPath dataPath = globals->get_fg_home();
-                globals->loadUserSettings(dataPath);
+            if (!options->isOptionSet("ignore-autosave")) {
+                globals->loadUserSettings();
             }
         }
     }
@@ -250,6 +258,7 @@ static void fgIdleFunction ( void ) {
             fgSetVideoOptions();
             idle_state+=2;
             fgSplashProgress("loading-aircraft-list");
+            fgSetBool("/sim/rendering/initialized", true);
         }
 
     } else if ( idle_state == 2 ) {
@@ -293,7 +302,7 @@ static void fgIdleFunction ( void ) {
         flightgear::initPosition();
         flightgear::initTowerLocationListener();
         
-        simgear::SGModelLib::init(globals->get_fg_root(), globals->get_props());
+        simgear::SGModelLib::init(globals->get_fg_root().local8BitStr(), globals->get_props());
         
         TimeManager* timeManager = (TimeManager*) globals->get_subsystem("time");
         timeManager->init();
@@ -394,21 +403,11 @@ static void upper_case_property(const char *name)
     p->addChangeListener(muc);
 }
 
-// see http://code.google.com/p/flightgear-bugs/issues/detail?id=385
-// for the details of this.
-static void ATIScreenSizeHack()
-{
-    osg::ref_ptr<osg::Camera> hackCam = new osg::Camera;
-    hackCam->setRenderOrder(osg::Camera::PRE_RENDER);
-    int prettyMuchAnyInt = 1;
-    hackCam->setViewport(0, 0, prettyMuchAnyInt, prettyMuchAnyInt);
-    globals->get_renderer()->addCamera(hackCam, false);
-}
-
-// Propose NVIDIA Optimus to use high-end GPU
+// Propose NVIDIA Optimus / AMD Xpress to use high-end GPU
 #if defined(SG_WINDOWS)
 extern "C" {
     _declspec(dllexport) DWORD NvOptimusEnablement = 0x00000001;
+    _declspec(dllexport) int AmdPowerXpressRequestHighPerformance = 1;
 }
 #endif
 
@@ -471,6 +470,18 @@ int fgMainInit( int argc, char **argv )
     upper_case_property("/sim/tower/airport-id");
     upper_case_property("/autopilot/route-manager/input");
 
+// check if the launcher is reuested, since it affects config file parsing
+    bool showLauncher = flightgear::Options::checkForArg(argc, argv, "launcher");
+    // an Info.plist bundle can't define command line arguments, but it can set
+    // environment variables. This avoids needed a wrapper shell-script on OS-X.
+    showLauncher |= (::getenv("FG_LAUNCHER") != 0);
+    if (showLauncher) {
+        // to minimise strange interactions when launcher and config files
+        // set overlaping options, we disable the default files. Users can
+        // still explicitly request config files via --config options if they choose.
+        flightgear::Options::sharedInstance()->setShouldLoadDefaultConfig(false);
+    }
+
     // Load the configuration parameters.  (Command line options
     // override config file options.  Config file options override
     // defaults.)
@@ -482,11 +493,6 @@ int fgMainInit( int argc, char **argv )
     }
 
 #if defined(HAVE_QT)
-    bool showLauncher = flightgear::Options::checkForArg(argc, argv, "launcher");
-    // an Info.plist bundle can't define command line arguments, but it can set
-    // environment variables. This avoids needed a wrapper shell-script on OS-X.
-    showLauncher |= (::getenv("FG_LAUNCHER") != 0);
-
     if (showLauncher) {
         flightgear::initApp(argc, argv);
         if (!flightgear::runLauncherDialog()) {
@@ -527,11 +533,6 @@ int fgMainInit( int argc, char **argv )
     fntInit();
     fgSplashInit();
 
-    if (fgGetBool("/sim/ati-viewport-hack", true)) {
-        SG_LOG(SG_GENERAL, SG_ALERT, "Enabling ATI viewport hack");
-        ATIScreenSizeHack();
-    }
-    
     fgOutputSettings();
     
     //try to disable the screensaver
