@@ -22,6 +22,8 @@
 #  include "config.h"
 #endif
 
+#include <boost/tuple/tuple.hpp>
+
 // simgear
 #include <simgear/props/props_io.hxx>
 #include <simgear/structure/exception.hxx>
@@ -34,6 +36,7 @@
 #include <Airports/runways.hxx>
 #include <Airports/airport.hxx>
 #include <Airports/dynamics.hxx>
+#include <Airports/groundnetwork.hxx>
 #include <AIModel/AIManager.hxx>
 #include <GUI/MessageBox.hxx>
 
@@ -115,6 +118,26 @@ void initTowerLocationListener() {
   ->addChangeListener(ntcl, true );
 }
 
+static void setInitialPosition(const SGGeod& aPos, double aHeadingDeg)
+{
+    // presets
+    fgSetDouble("/sim/presets/longitude-deg", aPos.getLongitudeDeg() );
+    fgSetDouble("/sim/presets/latitude-deg", aPos.getLatitudeDeg() );
+    fgSetDouble("/sim/presets/heading-deg", aHeadingDeg );
+
+    // other code depends on the actual values being set ...
+    fgSetDouble("/position/longitude-deg",  aPos.getLongitudeDeg() );
+    fgSetDouble("/position/latitude-deg",  aPos.getLatitudeDeg() );
+    fgSetDouble("/orientation/heading-deg", aHeadingDeg );
+}
+
+static bool isMPEnabled()
+{
+    // crude test, but sufficient for what we need
+    std::string txAddress = fgGetString("/sim/multiplay/txhost");
+    return !txAddress.empty();
+}
+
 static void fgApplyStartOffset(const SGGeod& aStartPos, double aHeading, double aTargetHeading = HUGE_VAL)
 {
   SGGeod startPos(aStartPos);
@@ -137,15 +160,36 @@ static void fgApplyStartOffset(const SGGeod& aStartPos, double aHeading, double
     startPos = offset;
   }
   
-  // presets
-  fgSetDouble("/sim/presets/longitude-deg", startPos.getLongitudeDeg() );
-  fgSetDouble("/sim/presets/latitude-deg", startPos.getLatitudeDeg() );
-  fgSetDouble("/sim/presets/heading-deg", aHeading );
-  
-  // other code depends on the actual values being set ...
-  fgSetDouble("/position/longitude-deg",  startPos.getLongitudeDeg() );
-  fgSetDouble("/position/latitude-deg",  startPos.getLatitudeDeg() );
-  fgSetDouble("/orientation/heading-deg", aHeading );
+    setInitialPosition(startPos, aHeading);
+}
+
+boost::tuple<SGGeod, double> runwayStartPos(FGRunwayRef runway)
+{
+    fgSetString("/sim/atc/runway", runway->ident().c_str());
+    double offsetNm = fgGetDouble("/sim/presets/offset-distance-nm");
+    double startOffset = fgGetDouble("/sim/airport/runways/start-offset-m", 5.0);
+    SGGeod pos = runway->pointOnCenterline(startOffset);
+
+    if (isMPEnabled() && (fabs(offsetNm) <0.1)) {
+        SG_LOG( SG_GENERAL, SG_WARN, "Requested to start on " << runway->airport()->ident() << "/" <<
+               runway->ident() << ", MP is enabled so computing hold short position to avoid runway incursion");
+
+        FGGroundNetwork* groundNet = runway->airport()->groundNetwork();
+        // add a margin, try to keep the entire aeroplane comfortable off the
+        // runway. 
+        double margin = startOffset + (runway->widthM() * 1.5);
+        FGTaxiNodeRef taxiNode = groundNet ? groundNet->findNearestNodeOffRunway(pos, runway, margin) : 0;
+        if (taxiNode) {
+            // set this so multiplayer.nas can inform the user
+            fgSetBool("/sim/presets/avoided-mp-runway", true);
+            return boost::make_tuple(taxiNode->geod(), SGGeodesy::courseDeg(taxiNode->geod(), pos));
+        }
+
+        // if we couldn't find a suitable taxi-node, give up. Guessing a position
+        // causes too much pain (starting in the water or similar bad things)
+    }
+
+    return boost::make_tuple(pos, runway->headingDeg());
 }
 
 // Set current_options lon/lat given an airport id and heading (degrees)
@@ -160,7 +204,7 @@ static bool setPosFromAirportIDandHdg( const string& id, double tgt_hdg ) {
   
   const FGAirport* apt = fgFindAirportID(id);
   if (!apt) return false;
-  
+
   SGGeod startPos;
   double heading = tgt_hdg;
   if (apt->type() == FGPositioned::HELIPORT) {
@@ -171,13 +215,11 @@ static bool setPosFromAirportIDandHdg( const string& id, double tgt_hdg ) {
     }
   } else {
     FGRunway* r = apt->findBestRunwayForHeading(tgt_hdg);
-    fgSetString("/sim/atc/runway", r->ident().c_str());
-    startPos = r->pointOnCenterline(fgGetDouble("/sim/airport/runways/start-offset-m", 5.0));
-    heading = r->headingDeg();
+      boost::tie(startPos, heading) = runwayStartPos(r);
   }
 
-  fgApplyStartOffset(startPos, heading, tgt_hdg);
-  return true;
+    fgApplyStartOffset(startPos, heading);
+    return true;
 }
 
 // Set current_options lon/lat given an airport id and parkig position name
@@ -190,22 +232,25 @@ static bool fgSetPosFromAirportIDandParkpos( const string& id, const string& par
   if ( id.empty() )
     return false;
   
-  // can't see an easy way around this const_cast at the moment
-  FGAirport* apt = const_cast<FGAirport*>(fgFindAirportID(id));
+  const FGAirport* apt = fgFindAirportID(id);
   if (!apt) {
     SG_LOG( SG_GENERAL, SG_ALERT, "Failed to find airport " << id );
     return false;
   }
+
   FGAirportDynamicsRef dcs = apt->getDynamics();
   if (!dcs) {
-    SG_LOG( SG_GENERAL, SG_ALERT,
-           "Airport " << id << "does not appear to have parking information available");
-    return false;
+      // this happens during initPosition(), because the dynamics manager and
+      // ATC manager aren't running yet. We want to set an interim position
+      // so METAR and tile-loading can proceed, and then we're set the final
+      // position by call this this function again during finalizePosition
+      setInitialPosition(apt->geod(), 0.0);
+      return true;
   }
   
   ParkingAssignment pka;
   double radius = fgGetDouble("/sim/dimensions/radius-m");
-  if ((parkpos == string("AVAILABLE")) && (radius > 0)) {
+  if ((parkpos == "AVAILABLE") && (radius > 0)) {
     
     try {
       acData = globals->get_fg_home();
@@ -213,24 +258,24 @@ static bool fgSetPosFromAirportIDandParkpos( const string& id, const string& par
       string acfile = fgGetString("/sim/aircraft") + string(".xml");
       acData.append(acfile);
       SGPropertyNode root;
-      readProperties(acData.str(), &root);
+      readProperties(acData, &root);
       SGPropertyNode * node = root.getNode("sim");
       fltType    = node->getStringValue("aircraft-class", "NONE"     );
       acOperator = node->getStringValue("aircraft-operator", "NONE"     );
     } catch (const sg_exception &) {
       SG_LOG(SG_GENERAL, SG_INFO,
-             "Could not load aircraft aircrat type and operator information from: " << acData.str() << ". Using defaults");
+             "Could not load aircraft aircrat type and operator information from: " << acData << ". Using defaults");
       
       // cout << path.str() << endl;
     }
     if (fltType.empty() || fltType == "NONE") {
       SG_LOG(SG_GENERAL, SG_INFO,
-             "Aircraft type information not found in: " << acData.str() << ". Using default value");
+             "Aircraft type information not found in: " << acData << ". Using default value");
       fltType = fgGetString("/sim/aircraft-class"   );
     }
     if (acOperator.empty() || fltType == "NONE") {
       SG_LOG(SG_GENERAL, SG_INFO,
-             "Aircraft operator information not found in: " << acData.str() << ". Using default value");
+             "Aircraft operator information not found in: " << acData << ". Using default value");
       acOperator = fgGetString("/sim/aircraft-operator"   );
     }
     
@@ -285,9 +330,10 @@ static bool fgSetPosFromAirportIDandRwy( const string& id, const string& rwy, bo
 
   if (apt->hasRunwayWithIdent(rwy)) {
       FGRunway* r(apt->getRunwayByIdent(rwy));
-      fgSetString("/sim/atc/runway", r->ident().c_str());
-      SGGeod startPos = r->pointOnCenterline( fgGetDouble("/sim/airport/runways/start-offset-m", 5.0));
-      fgApplyStartOffset(startPos, r->headingDeg());
+      SGGeod startPos;
+      double heading;
+      boost::tie(startPos, heading) = runwayStartPos(r);
+      fgApplyStartOffset(startPos, heading);
       return true;
   } else if (apt->hasHelipadWithIdent(rwy)) {
       FGHelipad* h(apt->getHelipadByIdent(rwy));
@@ -537,6 +583,9 @@ bool initPosition()
   
   if ( !set_pos && !apt.empty() && !parkpos.empty() ) {
     // An airport + parking position is requested
+    // since this depends on parking, which is part of dynamics, and hence
+    // also depends on ATC (the ground controller), we need to defer this
+    // until position finalisation
     if ( fgSetPosFromAirportIDandParkpos( apt, parkpos ) ) {
       // set tower position
       fgSetString("/sim/airport/closest-airport-id",  apt.c_str());
@@ -600,8 +649,8 @@ bool initPosition()
   
   if ( !set_pos ) {
     // No lon/lat specified, no airport specified, use the default airport
-    // TODO: don't hardcode this
-    const FGAirport* airport = fgFindAirportID("LEBL");
+    // TODO: don't hardcode this. Really.
+    const FGAirport* airport = fgFindAirportID("LSZH");
     if( airport ) {
       const SGGeod & airportGeod = airport->geod();
       fgSetDouble("/sim/presets/longitude-deg", airportGeod.getLongitudeDeg());
@@ -696,7 +745,10 @@ void finalizePosition()
      * loaded. => When requested "initial preset position" relates to a
      * carrier, recalculate the 'initial' position here 
      */
-    std::string carrier = fgGetString("/sim/presets/carrier","");
+    std::string carrier = fgGetString("/sim/presets/carrier");
+    std::string parkpos = fgGetString("/sim/presets/parkpos");
+    std::string apt = fgGetString("/sim/presets/airport-id");
+
     if (!carrier.empty())
     {
         SG_LOG(SG_GENERAL, SG_INFO, "finalizePositioned: re-init-ing position on carrier");
@@ -704,6 +756,10 @@ void finalizePosition()
         fgSetDouble("/sim/presets/longitude-deg", 9999);
         fgSetDouble("/sim/presets/latitude-deg", 9999);
         initPosition();
+    } else if (!apt.empty() && !parkpos.empty()) {
+        // parking position depends on ATC / dynamics code to assign spaces,
+        // so we wait until this point to initialise
+        fgSetPosFromAirportIDandParkpos(apt, parkpos);
     } else {
         done = finalizeMetar();
     }
