@@ -22,6 +22,7 @@
 #  include "config.h"
 #endif
 
+#include <istream>              // std::ws
 #include "poidb.hxx"
 
 #include <simgear/compiler.h>
@@ -61,7 +62,7 @@ static PositionedID readPOIFromStream(std::istream& aStream, NavDataCache* cache
         return 0;
     }
 
-    aStream >> skipws;
+    aStream >> std::ws;
     if (aStream.peek() == '#') {
         aStream >> skipeol;
         return 0;
@@ -92,9 +93,9 @@ static PositionedID readPOIFromStream(std::istream& aStream, NavDataCache* cache
 // load and initialize the POI database
 bool poiDBInit(const SGPath& path)
 {
-    sg_gzifstream in( path.str() );
+    sg_gzifstream in( path );
     if ( !in.is_open() ) {
-        SG_LOG( SG_NAVAID, SG_ALERT, "Cannot open file: " << path.str() );
+        SG_LOG( SG_NAVAID, SG_ALERT, "Cannot open file: " << path );
       return false;
     }
 
