@@ -16,7 +16,72 @@
 #include <Navaids/positioned.hxx>
 
 namespace flightgear {
-  bool geocRadialIntersection(const SGGeoc& a, double r1, const SGGeoc& b, double r2, SGGeoc& result);
+
+  // implementation of
+  // http://williams.best.vwh.net/avform.htm#Intersection
+  bool geocRadialIntersection(const SGGeoc& a, double r1, const SGGeoc& b, double r2, SGGeoc& result)
+  {
+    double crs13 = r1 * SG_DEGREES_TO_RADIANS;
+    double crs23 = r2 * SG_DEGREES_TO_RADIANS;
+    double dst12 = SGGeodesy::distanceRad(a, b);
+
+    //IF sin(lon2-lon1)<0
+    // crs12=acos((sin(lat2)-sin(lat1)*cos(dst12))/(sin(dst12)*cos(lat1)))
+    // crs21=2.*pi-acos((sin(lat1)-sin(lat2)*cos(dst12))/(sin(dst12)*cos(lat2)))
+    // ELSE
+    // crs12=2.*pi-acos((sin(lat2)-sin(lat1)*cos(dst12))/(sin(dst12)*cos(lat1)))
+    // crs21=acos((sin(lat1)-sin(lat2)*cos(dst12))/(sin(dst12)*cos(lat2)))
+    // ENDIF
+
+    double sinLat1 = sin(a.getLatitudeRad());
+    double cosLat1 = cos(a.getLatitudeRad());
+    double sinDst12 = sin(dst12);
+    double cosDst12 = cos(dst12);
+
+    double crs12 = SGGeodesy::courseRad(a, b),
+      crs21 = SGGeodesy::courseRad(b, a);
+
+
+    // normalise to -pi .. pi range
+    double ang1 = SGMiscd::normalizeAngle(crs13-crs12);
+    double ang2 = SGMiscd::normalizeAngle(crs21-crs23);
+
+    if ((sin(ang1) == 0.0) && (sin(ang2) == 0.0)) {
+      SG_LOG(SG_INSTR, SG_INFO, "geocRadialIntersection: infinity of intersections");
+      return false;
+    }
+
+    if ((sin(ang1)*sin(ang2))<0.0) {
+     // SG_LOG(SG_INSTR, SG_INFO, "geocRadialIntersection: intersection ambiguous:"
+      //       << ang1 << " " << ang2 << " sin1 " << sin(ang1) << " sin2 " << sin(ang2));
+      return false;
+    }
+
+    ang1 = fabs(ang1);
+    ang2 = fabs(ang2);
+
+    //ang3=acos(-cos(ang1)*cos(ang2)+sin(ang1)*sin(ang2)*cos(dst12))
+    //dst13=atan2(sin(dst12)*sin(ang1)*sin(ang2),cos(ang2)+cos(ang1)*cos(ang3))
+    //lat3=asin(sin(lat1)*cos(dst13)+cos(lat1)*sin(dst13)*cos(crs13))
+
+    //lon3=mod(lon1-dlon+pi,2*pi)-pi
+
+    double ang3 = acos(-cos(ang1) * cos(ang2) + sin(ang1) * sin(ang2) * cosDst12);
+    double dst13 = atan2(sinDst12 * sin(ang1) * sin(ang2), cos(ang2) + cos(ang1)*cos(ang3));
+
+    SGGeoc pt3;
+    SGGeodesy::advanceRadM(a, crs13, dst13 * SG_RAD_TO_NM * SG_NM_TO_METER, pt3);
+
+    double lat3 = asin(sinLat1 * cos(dst13) + cosLat1 * sin(dst13) * cos(crs13));
+
+    //dlon=atan2(sin(crs13)*sin(dst13)*cos(lat1),cos(dst13)-sin(lat1)*sin(lat3))
+    double dlon = atan2(sin(crs13)*sin(dst13)*cosLat1, cos(dst13)- (sinLat1 * sin(lat3)));
+    double lon3 = SGMiscd::normalizeAngle(-a.getLongitudeRad()-dlon);
+
+    result = SGGeoc::fromRadM(-lon3, lat3, a.getRadiusM());
+    //result = pt3;
+    return true;
+  }
 }
 
 using namespace flightgear;
@@ -114,8 +179,8 @@ struct TurnInfo
 };
 
 /**
- * given a turn exit position and heading, and an arbitrary origin postion, 
- * compute the turn center / angle the matches. Certain configurations may
+ * given a turn exit position and heading, and an arbitrary origin position,
+ * compute the turn center / angle that matches. Certain configurations may
  * fail, especially if the origin is less than two turn radii from the exit pos.
  */
 TurnInfo turnCenterAndAngleFromExit(const SGGeod& pt, double outHeadingDeg,
@@ -134,7 +199,7 @@ TurnInfo turnCenterAndAngleFromExit(const SGGeod& pt, double outHeadingDeg,
     double courseToTC, distanceToTC, az2;
     SGGeodesy::inverse(origin, r.turnCenter, courseToTC, az2, distanceToTC);
     if (distanceToTC < turnRadiusM) {
-        SG_LOG(SG_NAVAID, SG_WARN, "turnCenterAndAngleFromExit: origin point to close to turn center");
+        SG_LOG(SG_NAVAID, SG_WARN, "turnCenterAndAngleFromExit: origin point too close to turn center");
         return r;
     }
 
@@ -173,6 +238,7 @@ public:
     turnEntryAngle(0.0),
     turnExitAngle(0.0),
     turnRadius(0.0),
+    legCourseTrue(0.0),
     pathDistanceM(0.0),
     turnPathDistanceM(0.0),
     overflightCompensationAngle(0.0),
@@ -188,6 +254,8 @@ public:
       if (ty == "hdgToAlt") {
         flyOver = true;
       }
+    } else if (ty == "discontinuity") {
+
     } else {
       pos = wpt->position();
       posValid = true;
@@ -219,8 +287,11 @@ public:
       }
     }
 
-    if (posValid && !legCourseValid && previous.posValid) {
-    // check for duplicate points now
+    if (wpt->type() == "via") {
+        // even though both ends may be known, we don't
+        // want to compute a leg course for a VIA
+    } else if (posValid && !legCourseValid && previous.posValid) {
+        // check for duplicate points now
       if (previous.wpt->matches(wpt)) {
           skipped = true;
       }
@@ -235,7 +306,7 @@ public:
             legCourseTrue = SGGeodesy::courseDeg(previous.pos, pos);
             legCourseValid = true;
         }
-    }
+    } // of not a VIA
   }
 
   void computeLegCourse(const WayptData& previous, double radiusM)
@@ -244,8 +315,12 @@ public:
           return;
       }
 
-      if (wpt->type() == "hold") {
-
+      if ((wpt->type() == "hold") ||
+              (wpt->type() == "discontinuity") ||
+              (wpt->type()  == "via"))
+      {
+          // do nothing, we can't compute a valid leg course for these types
+          // we'll generate shrap turns in the path but that's no problem.
       } else if (wpt->type() == "runway") {
           FGRunway* rwy = static_cast<RunwayWaypt*>(wpt.get())->runway();
           flyOver = true;
@@ -274,7 +349,7 @@ public:
               legCourseTrue = wpt->headingRadialDeg() + magVar;
               legCourseValid = true;
           } // of pos not valid
-      } // of neither hold nor runway
+      } // of general case
   }
 
     SGGeod pointOnEntryTurnFromHeading(double headingDeg) const
@@ -310,13 +385,14 @@ public:
           }
       } else {
           // happens for first leg
-          legCourseValid = true;
           if (isRunway) {
+              legCourseValid = true;
               FGRunway* rwy = static_cast<RunwayWaypt*>(wpt.get())->runway();
               turnExitAngle = next.legCourseTrue - rwy->headingDeg();
               legCourseTrue = rwy->headingDeg();
               flyOver = true;
           } else {
+              // don't set legCourseValid
               turnExitAngle = 0.0;
           }
       }
@@ -701,7 +777,7 @@ public:
     }
     
     if (index == 0) {
-      SG_LOG(SG_NAVAID, SG_WARN, "findPreceedingKnownAltitude: no preceeding altitude value found");
+      SG_LOG(SG_NAVAID, SG_WARN, "findPreceedingKnownAltitude: no preceding altitude value found");
       return -1;
     }
     
@@ -709,7 +785,7 @@ public:
     return findPreceedingKnownAltitude(index - 1);
   }
   
-  int findNextKnownAltitude(int index) const
+  int findNextKnownAltitude(unsigned int index) const
   {
     if (index >= waypoints.size()) {
       SG_LOG(SG_NAVAID, SG_WARN, "findNextKnownAltitude: no next altitude value found");
@@ -780,7 +856,7 @@ public:
       
       double tas = mach * Cs;
       
-#if 0
+/*
       P_0= 29.92126 "Hg = 1013.25 mB = 2116.2166 lbs/ft^2
       P= P_0*(1-6.8755856*10^-6*PA)^5.2558797, pressure altitude, PA<36,089.24ft
       CS= 38.967854*sqrt(T+273.15)  where T is the (static/true) OAT in Celsius.
@@ -788,7 +864,7 @@ public:
       DP=P_0*((1 + 0.2*(IAS/CS_0)^2)^3.5 -1)
       M=(5*( (DP/P + 1)^(2/7) -1) )^0.5   (*)
       TAS= M*CS
-#endif
+*/
     }
 #endif
   }
@@ -862,6 +938,10 @@ RoutePath::RoutePath(const flightgear::FlightPlan* fp) :
     commonInit();
 }
 
+RoutePath::~RoutePath()
+{
+}
+
 void RoutePath::commonInit()
 {
   d->initPerfData();
@@ -910,6 +990,7 @@ void RoutePath::commonInit()
     } else {
       // final waypt, fix up some data
       d->waypoints[i].turnExitPos = d->waypoints[i].pos;
+      d->waypoints[i].turnEntryPos = d->waypoints[i].pos;
     }
     
     // now turn is computed, can resolve distances
@@ -931,6 +1012,14 @@ SGGeodVec RoutePath::pathForIndex(int index) const
       // ideally we'd show a stippled line to connect the route?
     return SGGeodVec();
   }
+
+  if (ty == "discontinuity") {
+    return SGGeodVec(); // no points for a discontinuity of course
+  }
+
+  if (ty == "via") {
+      return pathForVia(static_cast<Via*>(d->waypoints[index].wpt.get()), index);
+  }
   
   if (ty== "hold") {
     return pathForHold((Hold*) d->waypoints[index].wpt.get());
@@ -992,6 +1081,28 @@ SGGeod RoutePath::positionForIndex(int index) const
   return d->waypoints[index].pos;
 }
 
+SGGeodVec RoutePath::pathForVia(Via* via, int index) const
+{
+    // previous waypoint must be valid for a VIA
+    if ((index == 0) || !d->waypoints[index-1].posValid) {
+        return SGGeodVec();
+    }
+
+    const WayptData& prev(d->waypoints[index-1]);
+    WayptVec enrouteWaypoints = via->expandToWaypoints(prev.wpt);
+    SGGeodVec r;
+
+    WayptVec::const_iterator it;
+    SGGeod legStart = prev.wpt->position();
+    for (it = enrouteWaypoints.begin(); it != enrouteWaypoints.end(); ++it) {
+        // interpolate directly into the result vector
+        interpolateGreatCircle(legStart, (*it)->position(), r);
+        legStart = (*it)->position();
+    }
+
+    return r;
+}
+
 SGGeodVec RoutePath::pathForHold(Hold* hold) const
 {
   int turnSteps = 16;
@@ -1048,6 +1159,11 @@ double RoutePath::computeDistanceForIndex(int index) const
         return 0.0;
     }
 
+
+    if (d->waypoints[index].wpt->type() == "via") {
+        return distanceForVia(static_cast<Via*>(d->waypoints[index].wpt.get()), index);
+    }
+
     const WayptData& prev(d->previousValidWaypoint(index));
   double dist = SGGeodesy::distanceM(prev.turnExitPos,
                               d->waypoints[index].turnEntryPos);
@@ -1061,11 +1177,38 @@ double RoutePath::computeDistanceForIndex(int index) const
   return dist;
 }
 
+double RoutePath::distanceForVia(Via* via, int index) const
+{
+    // previous waypoint must be valid for a VIA
+    if ((index == 0) || !d->waypoints[index-1].posValid) {
+        return 0.0;
+    }
+
+    const WayptData& prev(d->waypoints[index-1]);
+    WayptVec enrouteWaypoints = via->expandToWaypoints(prev.wpt);
+    double dist = 0.0;
+
+    WayptVec::const_iterator it;
+    SGGeod legStart = prev.wpt->position();
+    for (it = enrouteWaypoints.begin(); it != enrouteWaypoints.end(); ++it) {
+        dist += SGGeodesy::distanceM(legStart, (*it)->position());
+        legStart = (*it)->position();
+    }
+
+    return dist;
+}
+
 double RoutePath::trackForIndex(int index) const
 {
+
     if (d->waypoints[index].skipped)
         return trackForIndex(index - 1);
-  return d->waypoints[index].legCourseTrue;
+
+    const WayptData& wd(d->waypoints[index]);
+    if (!wd.legCourseValid)
+        return 0.0;
+
+    return wd.legCourseTrue;
 }
 
 double RoutePath::distanceForIndex(int index) const
@@ -1121,8 +1264,12 @@ SGGeod RoutePath::positionForDistanceFrom(int index, double distanceM) const
         return d->waypoints[sz - 1].pos;
     }
 
+
     const WayptData& wpt(d->waypoints[index]);
     const WayptData& next(d->waypoints[index+1]);
+    if (next.wpt->type() == "via") {
+        return positionAlongVia(static_cast<Via*>(next.wpt.get()), index, distanceM);
+    }
 
     if (wpt.turnPathDistanceM > distanceM) {
         // on the exit path of current wpt
@@ -1140,3 +1287,9 @@ SGGeod RoutePath::positionForDistanceFrom(int index, double distanceM) const
     // linear between turn exit and turn entry points
     return SGGeodesy::direct(wpt.turnExitPos, next.legCourseTrue, distanceM);
 }
+
+SGGeod RoutePath::positionAlongVia(Via* via, int previousIndex, double distanceM) const
+{
+    SG_LOG(SG_NAVAID, SG_ALERT, "RoutePath::positionAlongVia not implemented");
+    return SGGeod();
+}
