@@ -24,6 +24,8 @@
 #include "ScreenshotUriHandler.hxx"
 #include "PropertyUriHandler.hxx"
 #include "JsonUriHandler.hxx"
+#include "FlightHistoryUriHandler.hxx"
+#include "PkgUriHandler.hxx"
 #include "RunUriHandler.hxx"
 #include "NavdbUriHandler.hxx"
 #include "PropertyChangeObserver.hxx"
@@ -451,6 +453,16 @@ void MongooseHttpd::init()
       _uriHandler.push_back(new flightgear::http::JsonUriHandler(uri));
     }
 
+    if ((uri = n->getStringValue("pkg"))[0] != 0) {
+      SG_LOG(SG_NETWORK, SG_INFO, "httpd: adding pkg uri handler at " << uri);
+      _uriHandler.push_back(new flightgear::http::PkgUriHandler(uri));
+    }
+
+    if ((uri = n->getStringValue("flighthistory"))[0] != 0) {
+      SG_LOG(SG_NETWORK, SG_INFO, "httpd: adding flighthistory uri handler at " << uri);
+      _uriHandler.push_back(new flightgear::http::FlightHistoryUriHandler(uri));
+    }
+
     if ((uri = n->getStringValue("run"))[0] != 0) {
       SG_LOG(SG_NETWORK, SG_INFO, "httpd: adding run uri handler at " << uri);
       _uriHandler.push_back(new flightgear::http::RunUriHandler(uri));
@@ -479,6 +491,8 @@ void MongooseHttpd::init()
       string rewrites = n->getStringValue("url-rewrites", "");
       string_list rwl = simgear::strutils::split(rewrites, ",");
       rwl.push_back(string("/aircraft-dir/=") + fgGetString("/sim/aircraft-dir") + "/" );
+      rwl.push_back(string("/fg-home/=") + fgGetString("/sim/fg-home") + "/" );
+      rwl.push_back(string("/fg-root/=") + fgGetString("/sim/fg-root") + "/" );
       rewrites.clear();
       for (string_list::iterator it = rwl.begin(); it != rwl.end(); ++it) {
         string_list rw_entries = simgear::strutils::split(*it, "=");
