@@ -284,9 +284,11 @@ private:
 FGScenery::FGScenery() :
     _listener(NULL)
 {
-    SG_LOG( SG_TERRAIN, SG_INFO, "Initializing scenery subsystem" );
     // keep reference to pager singleton, so it cannot be destroyed while FGScenery lives
     _pager = FGScenery::getPagerSingleton();
+
+    // Initialise the state of the scene graph.
+    _inited = false;
 }
 
 FGScenery::~FGScenery()
@@ -297,6 +299,10 @@ FGScenery::~FGScenery()
 
 // Initialize the Scenery Management system
 void FGScenery::init() {
+    // Already set up.
+    if (_inited)
+        return;
+
     // Scene graph root
     scene_graph = new osg::Switch;
     scene_graph->setName( "FGScenery" );
@@ -328,20 +334,34 @@ void FGScenery::init() {
     interiorLOD->addChild(interior_branch.get(), 0.0, 50.0);
     aircraft_branch->addChild( interiorLOD );
     
-    // Initials values needed by the draw-time object loader
-    sgUserDataInit( globals->get_props() );
+    // Set up the particle system as a directly accessible branch of the scene graph.
+    particles_branch = simgear::Particles::getCommonRoot();
+    particles_branch->setName("Particles");
+    scene_graph->addChild(particles_branch.get());
+    simgear::GlobalParticleCallback::setSwitch(fgGetNode("/sim/rendering/particles", true));
   
+    // Set up the precipitation system.
+    precipitation_branch = new osg::Group;
+    precipitation_branch->setName("Precipitation");
+    scene_graph->addChild(precipitation_branch.get());
+
     _listener = new ScenerySwitchListener(this);
+
+    // Toggle the setup flag.
+    _inited = true;
 }
 
 void FGScenery::shutdown()
 {
-    sgUserDataInit( NULL );
-    
     scene_graph = NULL;
     terrain_branch = NULL;
     models_branch = NULL;
     aircraft_branch = NULL;
+    particles_branch = NULL;
+    precipitation_branch = NULL;
+
+    // Toggle the setup flag.
+    _inited = false;
 }
 
 
