@@ -24,7 +24,9 @@
 #include <simgear/props/props.hxx>
 #include <simgear/math/sg_random.h>
 #include <simgear/misc/sg_path.hxx>
+#include <simgear/misc/sgstream.hxx>
 #include <simgear/misc/sg_dir.hxx>
+#include <simgear/misc/strutils.hxx>
 #include <simgear/misc/SimpleMarkdown.hxx>
 #include <simgear/structure/commands.hxx>
 #include <simgear/math/sg_geodesy.hxx>
@@ -575,18 +577,17 @@ static naRef f_directory(naContext c, naRef me, int argc, naRef* args)
     if(argc != 1 || !naIsString(args[0]))
         naRuntimeError(c, "bad arguments to directory()");
 
-    std::string dirname = fgValidatePath(naStr_data(args[0]), false);
-    if(dirname.empty()) {
+    SGPath dirname = fgValidatePath(SGPath::fromUtf8(naStr_data(args[0])), false);
+    if(dirname.isNull()) {
         SG_LOG(SG_NASAL, SG_ALERT, "directory(): listing '" <<
         naStr_data(args[0]) << "' denied (unauthorized directory - authorization"
         " no longer follows symlinks; to authorize reading additional "
-        "directories, add them to --fg-aircraft)");
+        "directories, pass them to --allow-nasal-read)");
         // to avoid breaking dialogs, pretend it doesn't exist rather than erroring out
         return naNil();
     }
 
-    SGPath d0(dirname);
-    simgear::Dir d(d0);
+    simgear::Dir d(dirname);
     if(!d.exists()) return naNil();
     naRef result = naNewVector(c);
 
@@ -608,8 +609,8 @@ static naRef f_resolveDataPath(naContext c, naRef me, int argc, naRef* args)
         naRuntimeError(c, "bad arguments to resolveDataPath()");
 
     SGPath p = globals->resolve_maybe_aircraft_path(naStr_data(args[0]));
-    const char* pdata = p.c_str();
-    return naStr_fromdata(naNewString(c), const_cast<char*>(pdata), strlen(pdata));
+    std::string pdata = p.utf8Str();
+    return naStr_fromdata(naNewString(c), const_cast<char*>(pdata.c_str()), pdata.length());
 }
 
 static naRef f_findDataDir(naContext c, naRef me, int argc, naRef* args)
@@ -618,8 +619,8 @@ static naRef f_findDataDir(naContext c, naRef me, int argc, naRef* args)
         naRuntimeError(c, "bad arguments to findDataDir()");
     
     SGPath p = globals->find_data_dir(naStr_data(args[0]));
-    const char* pdata = p.c_str();
-    return naStr_fromdata(naNewString(c), const_cast<char*>(pdata), strlen(pdata));
+    std::string pdata = p.utf8Str();
+    return naStr_fromdata(naNewString(c), const_cast<char*>(pdata.c_str()), pdata.length());
 }
 
 class NasalCommand : public SGCommandMgr::Command
@@ -682,17 +683,25 @@ static naRef f_open(naContext c, naRef me, int argc, naRef* args)
     naRef mode = argc > 1 ? naStringValue(c, args[1]) : naNil();
     if(!naStr_data(file)) naRuntimeError(c, "bad argument to open()");
     const char* modestr = naStr_data(mode) ? naStr_data(mode) : "rb";
-    std::string filename = fgValidatePath(naStr_data(file),
+    SGPath filename = fgValidatePath(SGPath::fromUtf8(naStr_data(file)),
         strcmp(modestr, "rb") && strcmp(modestr, "r"));
-    if(filename.empty()) {
+    if(filename.isNull()) {
         SG_LOG(SG_NASAL, SG_ALERT, "open(): reading/writing '" <<
         naStr_data(file) << "' denied (unauthorized directory - authorization"
         " no longer follows symlinks; to authorize reading additional "
-        "directories, add them to --fg-aircraft)");
+        "directories, pass them to --allow-nasal-read)");
         naRuntimeError(c, "open(): access denied (unauthorized directory)");
         return naNil();
     }
-    f = fopen(filename.c_str(), modestr);
+
+#if defined(SG_WINDOWS)
+    std::wstring fp = filename.wstr();
+    std::wstring wmodestr = simgear::strutils::convertUtf8ToWString(modestr);
+    f = _wfopen(fp.c_str(), wmodestr.c_str());
+#else
+    std::string fp = filename.local8BitStr();
+    f = fopen(fp.c_str(), modestr);
+#endif
     if(!f) naRuntimeError(c, strerror(errno));
     return naIOGhost(c, f);
 }
@@ -717,25 +726,27 @@ static naRef f_parsexml(naContext c, naRef me, int argc, naRef* args)
         if(!(naIsNil(args[i]) || naIsFunc(args[i])))
             naRuntimeError(c, "parsexml(): callback argument not a function");
 
-    std::string file = fgValidatePath(naStr_data(args[0]), false);
-    if(file.empty()) {
+    SGPath file = fgValidatePath(SGPath::fromUtf8(naStr_data(args[0])), false);
+    if(file.isNull()) {
         SG_LOG(SG_NASAL, SG_ALERT, "parsexml(): reading '" <<
         naStr_data(args[0]) << "' denied (unauthorized directory - authorization"
         " no longer follows symlinks; to authorize reading additional "
-        "directories, add them to --fg-aircraft)");
+        "directories, pass them to --allow-nasal-read)");
         naRuntimeError(c, "parsexml(): access denied (unauthorized directory)");
         return naNil();
     }
-    std::ifstream input(file.c_str());
+
     NasalXMLVisitor visitor(c, argc, args);
     try {
-        readXML(input, visitor);
+        readXML(file, visitor);
     } catch (const sg_exception& e) {
-        naRuntimeError(c, "parsexml(): file '%s' %s",
-                file.c_str(), e.getFormattedMessage().c_str());
+        std::string fp = file.utf8Str();
+        naRuntimeError(c, "parsexml(): file '%s' %s", fp.c_str(), e.getFormattedMessage().c_str());
         return naNil();
     }
-    return naStr_fromdata(naNewString(c), file.c_str(), file.length());
+
+    std::string fs = file.utf8Str();
+    return naStr_fromdata(naNewString(c), fs.c_str(), fs.length());
 }
 
 /**
@@ -1032,7 +1043,7 @@ void FGNasalSys::addModule(string moduleName, simgear::PathList scripts)
         SGPropertyNode* module_node = nasal->getChild(moduleName,0,true);
         for (unsigned int i=0; i<scripts.size(); ++i) {
             SGPropertyNode* pFileNode = module_node->getChild("file",i,true);
-            pFileNode->setStringValue(scripts[i].c_str());
+            pFileNode->setStringValue(scripts[i].utf8Str());
         }
         if (!module_node->hasChild("enabled",0))
         {
@@ -1146,15 +1157,16 @@ void FGNasalSys::logError(naContext context)
 bool FGNasalSys::loadModule(SGPath file, const char* module)
 {
     int len = 0;
-    char* buf = readfile(file.c_str(), &len);
+    std::string pdata = file.local8BitStr();
+    char* buf = readfile(pdata.c_str(), &len);
     if(!buf) {
         SG_LOG(SG_NASAL, SG_ALERT,
-               "Nasal error: could not read script file " << file.c_str()
+               "Nasal error: could not read script file " << file
                << " into module " << module);
         return false;
     }
 
-    bool ok = createModule(module, file.c_str(), buf, len);
+    bool ok = createModule(module, pdata.c_str(), buf, len);
     delete[] buf;
     return ok;
 }
@@ -1211,6 +1223,12 @@ void FGNasalSys::deleteModule(const char* moduleName)
     naFreeContext(ctx);
 }
 
+naRef FGNasalSys::getModule(const char* moduleName)
+{
+    naRef mod = naHash_cget(_globals, (char*) moduleName);
+    return mod;
+}
+
 naRef FGNasalSys::parse(naContext ctx, const char* filename, const char* buf, int len)
 {
     int errLine = -1;
