@@ -596,11 +596,11 @@ FGRenderer::init( void )
     texture_path.append("Textures");
     texture_path.append("Sky");
     for (int i = 0; i < FGEnvironmentMgr::MAX_CLOUD_LAYERS; i++) {
-        SGCloudLayer * layer = new SGCloudLayer(texture_path.str());
+        SGCloudLayer * layer = new SGCloudLayer(texture_path.local8BitStr());
         _sky->add_cloud_layer(layer);
     }
     
-    _sky->texture_path( texture_path.str() );
+    _sky->texture_path( texture_path.local8BitStr() );
 
     if (!_classicalRenderer) {
         eventHandler->setChangeStatsCameraRenderOrder( true );
@@ -1173,7 +1173,7 @@ FGRenderer::buildDeferredFullscreenCamera( flightgear::CameraInfo* info, const F
     g->setUseDisplayList(false);
     simgear::EffectGeode* eg = new simgear::EffectGeode;
     osg::ref_ptr<SGReaderWriterOptions> opt;
-    opt = SGReaderWriterOptions::fromPath(globals->get_fg_root());
+    opt = SGReaderWriterOptions::fromPath(globals->get_fg_root().local8BitStr());
     opt->setPropertyNode(globals->get_props());
     simgear::Effect* effect = simgear::makeEffect(pass->effect, true, opt.get());
     if (effect) {
@@ -1226,7 +1226,7 @@ FGRenderer::buildDeferredDisplayCamera( osg::Camera* camera, flightgear::CameraI
     g->setUseDisplayList(false); //DEBUG
     simgear::EffectGeode* eg = new simgear::EffectGeode;
     osg::ref_ptr<SGReaderWriterOptions> opt;
-    opt = SGReaderWriterOptions::fromPath(globals->get_fg_root());
+    opt = SGReaderWriterOptions::fromPath(globals->get_fg_root().local8BitStr());
     opt->setPropertyNode(globals->get_props());
     simgear::Effect* effect = simgear::makeEffect(stage->effect, true, opt.get());
     if (!effect) {
@@ -1459,7 +1459,7 @@ FGRenderer::setupView( void )
     // Moon diameter:    3,476 kilometers
     // Sun diameter: 1,390,000 kilometers
     osg::ref_ptr<SGReaderWriterOptions> opt;
-    opt = SGReaderWriterOptions::fromPath(globals->get_fg_root());
+    opt = SGReaderWriterOptions::fromPath(globals->get_fg_root().local8BitStr());
     opt->setPropertyNode(globals->get_props());
     _sky->build( 80000.0, 80000.0,
                   463.3, 361.8,
@@ -1785,16 +1785,15 @@ SGVec2d uvFromIntersection(const Intersection& hit)
   return toSG( osg::Vec2d(tc1 * r1 + tc2 * r2 + tc3 * r3) );
 }
 
-bool
-FGRenderer::pick(std::vector<SGSceneryPick>& pickList, const osg::Vec2& windowPos)
+PickList FGRenderer::pick(const osg::Vec2& windowPos)
 {
-    // wipe out the return ...
-    pickList.clear();
+    PickList result;
+
     typedef osgUtil::LineSegmentIntersector::Intersections Intersections;
     Intersections intersections;
 
     if (!computeIntersections(CameraGroup::getDefault(), windowPos, intersections))
-        return false;
+        return result;
     for (Intersections::iterator hit = intersections.begin(),
              e = intersections.end();
          hit != e;
@@ -1819,12 +1818,12 @@ FGRenderer::pick(std::vector<SGSceneryPick>& pickList, const osg::Vec2& windowPo
                   sceneryPick.info.uv = uvFromIntersection(*hit);
 
                 sceneryPick.callback = pickCallback;
-                pickList.push_back(sceneryPick);
+                result.push_back(sceneryPick);
             } // of installed pick callbacks iteration
         } // of reverse node path walk
     }
     
-    return !pickList.empty();
+    return result;
 }
 
 void
